/****************************************************************************
** Meta object code from reading C++ file 'desktoppathssettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/desktoppaths/desktoppathssettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'desktoppathssettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20DesktopPathsSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto DesktopPathsSettings::qt_create_metaobjectdata<qt_meta_tag_ZN20DesktopPathsSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DesktopPathsSettings",
        "desktopLocationChanged",
        "",
        "documentsLocationChanged",
        "downloadsLocationChanged",
        "musicLocationChanged",
        "picturesLocationChanged",
        "videosLocationChanged",
        "publicLocationChanged",
        "templatesLocationChanged",
        "projectsLocationChanged",
        "desktopLocation",
        "QUrl",
        "defaultDesktopLocation",
        "documentsLocation",
        "defaultDocumentsLocation",
        "downloadsLocation",
        "defaultDownloadsLocation",
        "musicLocation",
        "defaultMusicLocation",
        "picturesLocation",
        "defaultPicturesLocation",
        "videosLocation",
        "defaultVideosLocation",
        "publicLocation",
        "defaultPublicLocation",
        "templatesLocation",
        "defaultTemplatesLocation",
        "projectsLocation",
        "defaultProjectsLocation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'desktopLocationChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'documentsLocationChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'downloadsLocationChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'musicLocationChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'picturesLocationChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videosLocationChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'publicLocationChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'templatesLocationChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'projectsLocationChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'desktopLocation'
        QtMocHelpers::PropertyData<QUrl>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'defaultDesktopLocation'
        QtMocHelpers::PropertyData<QUrl>(13, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'documentsLocation'
        QtMocHelpers::PropertyData<QUrl>(14, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'defaultDocumentsLocation'
        QtMocHelpers::PropertyData<QUrl>(15, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'downloadsLocation'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'defaultDownloadsLocation'
        QtMocHelpers::PropertyData<QUrl>(17, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'musicLocation'
        QtMocHelpers::PropertyData<QUrl>(18, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'defaultMusicLocation'
        QtMocHelpers::PropertyData<QUrl>(19, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'picturesLocation'
        QtMocHelpers::PropertyData<QUrl>(20, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'defaultPicturesLocation'
        QtMocHelpers::PropertyData<QUrl>(21, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'videosLocation'
        QtMocHelpers::PropertyData<QUrl>(22, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'defaultVideosLocation'
        QtMocHelpers::PropertyData<QUrl>(23, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'publicLocation'
        QtMocHelpers::PropertyData<QUrl>(24, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'defaultPublicLocation'
        QtMocHelpers::PropertyData<QUrl>(25, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'templatesLocation'
        QtMocHelpers::PropertyData<QUrl>(26, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'defaultTemplatesLocation'
        QtMocHelpers::PropertyData<QUrl>(27, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'projectsLocation'
        QtMocHelpers::PropertyData<QUrl>(28, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'defaultProjectsLocation'
        QtMocHelpers::PropertyData<QUrl>(29, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DesktopPathsSettings, qt_meta_tag_ZN20DesktopPathsSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DesktopPathsSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KCoreConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DesktopPathsSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DesktopPathsSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DesktopPathsSettingsE_t>.metaTypes,
    nullptr
} };

void DesktopPathsSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DesktopPathsSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->desktopLocationChanged(); break;
        case 1: _t->documentsLocationChanged(); break;
        case 2: _t->downloadsLocationChanged(); break;
        case 3: _t->musicLocationChanged(); break;
        case 4: _t->picturesLocationChanged(); break;
        case 5: _t->videosLocationChanged(); break;
        case 6: _t->publicLocationChanged(); break;
        case 7: _t->templatesLocationChanged(); break;
        case 8: _t->projectsLocationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::desktopLocationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::documentsLocationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::downloadsLocationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::musicLocationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::picturesLocationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::videosLocationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::publicLocationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::templatesLocationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopPathsSettings::*)()>(_a, &DesktopPathsSettings::projectsLocationChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->desktopLocation(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->defaultDesktopLocation(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->documentsLocation(); break;
        case 3: *reinterpret_cast<QUrl*>(_v) = _t->defaultDocumentsLocation(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->downloadsLocation(); break;
        case 5: *reinterpret_cast<QUrl*>(_v) = _t->defaultDownloadsLocation(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->musicLocation(); break;
        case 7: *reinterpret_cast<QUrl*>(_v) = _t->defaultMusicLocation(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->picturesLocation(); break;
        case 9: *reinterpret_cast<QUrl*>(_v) = _t->defaultPicturesLocation(); break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->videosLocation(); break;
        case 11: *reinterpret_cast<QUrl*>(_v) = _t->defaultVideosLocation(); break;
        case 12: *reinterpret_cast<QUrl*>(_v) = _t->publicLocation(); break;
        case 13: *reinterpret_cast<QUrl*>(_v) = _t->defaultPublicLocation(); break;
        case 14: *reinterpret_cast<QUrl*>(_v) = _t->templatesLocation(); break;
        case 15: *reinterpret_cast<QUrl*>(_v) = _t->defaultTemplatesLocation(); break;
        case 16: *reinterpret_cast<QUrl*>(_v) = _t->projectsLocation(); break;
        case 17: *reinterpret_cast<QUrl*>(_v) = _t->defaultProjectsLocation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDesktopLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 2: _t->setDocumentsLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 4: _t->setDownloadsLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 6: _t->setMusicLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 8: _t->setPicturesLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 10: _t->setVideosLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 12: _t->setPublicLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 14: _t->setTemplatesLocation(*reinterpret_cast<QUrl*>(_v)); break;
        case 16: _t->setProjectsLocation(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DesktopPathsSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DesktopPathsSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DesktopPathsSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KCoreConfigSkeleton::qt_metacast(_clname);
}

int DesktopPathsSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCoreConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void DesktopPathsSettings::desktopLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DesktopPathsSettings::documentsLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DesktopPathsSettings::downloadsLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DesktopPathsSettings::musicLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DesktopPathsSettings::picturesLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DesktopPathsSettings::videosLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DesktopPathsSettings::publicLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DesktopPathsSettings::templatesLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DesktopPathsSettings::projectsLocationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
