// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "keyboardsettingsdata.h"

#include "workspace_options.h"
#include "keyboardmiscsettings.h"
#include "keyboardsettings.h"




KeyboardSettingsData::KeyboardSettingsData(QObject *parent)
: KCModuleData(parent)
, m_workspaceOptions(new WorkspaceOptions(this))
, m_keyboardMiscSettings(new KeyboardMiscSettings(this))
, m_keyboardSettings(new KeyboardSettings(this))

{
autoRegisterSkeletons();
}

WorkspaceOptions *KeyboardSettingsData::workspaceOptions() const
{
    return m_workspaceOptions;
}

KeyboardMiscSettings *KeyboardSettingsData::keyboardMiscSettings() const
{
    return m_keyboardMiscSettings;
}

KeyboardSettings *KeyboardSettingsData::keyboardSettings() const
{
    return m_keyboardSettings;
}





#include "moc_keyboardsettingsdata.cpp"
