/****************************************************************************
** Meta object code from reading C++ file 'itemviewadapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../plasma-desktop-6.7.4/containments/desktop/plugins/folder/itemviewadapter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemviewadapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ItemViewAdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemViewAdapter::qt_create_metaobjectdata<qt_meta_tag_ZN15ItemViewAdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemViewAdapter",
        "QML.Element",
        "auto",
        "viewScrolled",
        "",
        "adapterViewChanged",
        "adapterModelChanged",
        "adapterIconSizeChanged",
        "adapterVisibleAreaChanged",
        "adapterView",
        "adapterModel",
        "QAbstractItemModel*",
        "adapterIconSize",
        "adapterVisibleArea",
        "QRect"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewScrolled'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adapterViewChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adapterModelChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adapterIconSizeChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adapterVisibleAreaChanged'
        QtMocHelpers::SignalData<void() const>(8, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'adapterView'
        QtMocHelpers::PropertyData<QObject*>(9, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'adapterModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'adapterIconSize'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'adapterVisibleArea'
        QtMocHelpers::PropertyData<QRect>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ItemViewAdapter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ItemViewAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<KAbstractViewAdapter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ItemViewAdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ItemViewAdapterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ItemViewAdapterE_t>.metaTypes,
    nullptr
} };

void ItemViewAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemViewAdapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewScrolled(); break;
        case 1: _t->adapterViewChanged(); break;
        case 2: _t->adapterModelChanged(); break;
        case 3: _t->adapterIconSizeChanged(); break;
        case 4: _t->adapterVisibleAreaChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemViewAdapter::*)() const>(_a, &ItemViewAdapter::viewScrolled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemViewAdapter::*)() const>(_a, &ItemViewAdapter::adapterViewChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemViewAdapter::*)() const>(_a, &ItemViewAdapter::adapterModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemViewAdapter::*)() const>(_a, &ItemViewAdapter::adapterIconSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ItemViewAdapter::*)() const>(_a, &ItemViewAdapter::adapterVisibleAreaChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->adapterView(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->adapterModel(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->adapterIconSize(); break;
        case 3: *reinterpret_cast<QRect*>(_v) = _t->adapterVisibleArea(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAdapterView(*reinterpret_cast<QObject**>(_v)); break;
        case 1: _t->setAdapterModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 2: _t->setAdapterIconSize(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setAdapterVisibleArea(*reinterpret_cast<QRect*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ItemViewAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemViewAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ItemViewAdapterE_t>.strings))
        return static_cast<void*>(this);
    return KAbstractViewAdapter::qt_metacast(_clname);
}

int ItemViewAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KAbstractViewAdapter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ItemViewAdapter::viewScrolled()const
{
    QMetaObject::activate(const_cast< ItemViewAdapter *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ItemViewAdapter::adapterViewChanged()const
{
    QMetaObject::activate(const_cast< ItemViewAdapter *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ItemViewAdapter::adapterModelChanged()const
{
    QMetaObject::activate(const_cast< ItemViewAdapter *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ItemViewAdapter::adapterIconSizeChanged()const
{
    QMetaObject::activate(const_cast< ItemViewAdapter *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ItemViewAdapter::adapterVisibleAreaChanged()const
{
    QMetaObject::activate(const_cast< ItemViewAdapter *>(this), &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
