// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef SPLASHSCREENDATA_H
#define SPLASHSCREENDATA_H

#include <QObject>

#include "kcmoduledata.h"



class SplashScreenSettings;


class SplashScreenData : public KCModuleData
{
    Q_OBJECT

public:
    explicit SplashScreenData(QObject *parent = nullptr);
    SplashScreenSettings *settings() const;


private:
    SplashScreenSettings *m_settings;

};



#endif
