/****************************************************************************
** Meta object code from reading C++ file 'kcm_keyboard.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/keyboard/kcm_keyboard.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm_keyboard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KCMKeyboardE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMKeyboard::qt_create_metaobjectdata<qt_meta_tag_ZN11KCMKeyboardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMKeyboard",
        "save",
        "",
        "load",
        "defaults",
        "resetShortcuts",
        "hasAccentSupport",
        "requestPreview",
        "model",
        "layout",
        "variant",
        "title",
        "workspaceOptions",
        "WorkspaceOptions*",
        "miscSettings",
        "KeyboardMiscSettings*",
        "keyboardSettings",
        "KeyboardSettings*",
        "userLayoutModel",
        "UserLayoutModel*",
        "shortcutHelper",
        "ShortcutHelper*",
        "xkbOptionsModel",
        "XkbOptionsModel*",
        "maxGroupCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetShortcuts'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'hasAccentSupport'
        QtMocHelpers::MethodData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'requestPreview'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Method 'requestPreview'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'workspaceOptions'
        QtMocHelpers::PropertyData<WorkspaceOptions*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'miscSettings'
        QtMocHelpers::PropertyData<KeyboardMiscSettings*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'keyboardSettings'
        QtMocHelpers::PropertyData<KeyboardSettings*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'userLayoutModel'
        QtMocHelpers::PropertyData<UserLayoutModel*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shortcutHelper'
        QtMocHelpers::PropertyData<ShortcutHelper*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'xkbOptionsModel'
        QtMocHelpers::PropertyData<XkbOptionsModel*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'maxGroupCount'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMKeyboard, qt_meta_tag_ZN11KCMKeyboardE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMKeyboard::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KCMKeyboardE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KCMKeyboardE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KCMKeyboardE_t>.metaTypes,
    nullptr
} };

void KCMKeyboard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMKeyboard *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load(); break;
        case 2: _t->defaults(); break;
        case 3: _t->resetShortcuts(); break;
        case 4: { bool _r = _t->hasAccentSupport();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->requestPreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 6: _t->requestPreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<WorkspaceOptions**>(_v) = _t->workspaceOptions(); break;
        case 1: *reinterpret_cast<KeyboardMiscSettings**>(_v) = _t->miscSettings(); break;
        case 2: *reinterpret_cast<KeyboardSettings**>(_v) = _t->keyboardSettings(); break;
        case 3: *reinterpret_cast<UserLayoutModel**>(_v) = _t->userLayoutModel(); break;
        case 4: *reinterpret_cast<ShortcutHelper**>(_v) = _t->shortcutHelper(); break;
        case 5: *reinterpret_cast<XkbOptionsModel**>(_v) = _t->xkbOptionsModel(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->maxGroupCount(); break;
        default: break;
        }
    }
}

const QMetaObject *KCMKeyboard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMKeyboard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KCMKeyboardE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMKeyboard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN12NumLockStateE_t {};
} // unnamed namespace

template <> constexpr inline auto NumLockState::qt_create_metaobjectdata<qt_meta_tag_ZN12NumLockStateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NumLockState",
        "NumLockOn",
        "NumLockOff",
        "NumLockUnchanged"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'NumLockState'
        QtMocHelpers::EnumData<NumLockState>(0, 0, QMC::EnumFlags{}).add({
            {    1, NumLockState::NumLockOn },
            {    2, NumLockState::NumLockOff },
            {    3, NumLockState::NumLockUnchanged },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN12NumLockStateE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN12NumLockStateE =
    NumLockState::qt_create_metaobjectdata<qt_meta_tag_ZN12NumLockStateE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN12NumLockStateE =
    qt_staticMetaObjectContent_ZN12NumLockStateE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN12NumLockStateE =
    qt_staticMetaObjectContent_ZN12NumLockStateE.relocatingData;

Q_CONSTINIT const QMetaObject NumLockState::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN12NumLockStateE.stringdata,
    qt_staticMetaObjectStaticContent_ZN12NumLockStateE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN12NumLockStateE.metaTypes,
    nullptr
} };

QT_WARNING_POP
