/****************************************************************************
** Meta object code from reading C++ file 'keyboard_daemon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/keyboard/keyboard_daemon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboard_daemon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KeyboardDaemonE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardDaemon::qt_create_metaobjectdata<qt_meta_tag_ZN14KeyboardDaemonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardDaemon",
        "D-Bus Interface",
        "org.kde.KeyboardLayouts",
        "layoutChanged",
        "",
        "index",
        "layoutListChanged",
        "configureKeyboard",
        "configureInput",
        "layoutChangedSlot",
        "layoutMapChanged",
        "setLayout",
        "QAction*",
        "action",
        "configChanged",
        "KConfigGroup",
        "group",
        "QByteArrayList",
        "names",
        "switchToNextLayout",
        "switchToPreviousLayout",
        "getLayout",
        "getLayoutsList",
        "QList<LayoutNames>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'layoutChanged'
        QtMocHelpers::SignalData<void(uint)>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::UInt, 5 },
        }}),
        // Signal 'layoutListChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'configureKeyboard'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureInput'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'layoutChangedSlot'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'layoutMapChanged'
        QtMocHelpers::SlotData<void()>(10, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLayout'
        QtMocHelpers::SlotData<bool(QAction *)>(11, 4, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'configChanged'
        QtMocHelpers::SlotData<void(const KConfigGroup &, const QByteArrayList &)>(14, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'switchToNextLayout'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'switchToPreviousLayout'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'setLayout'
        QtMocHelpers::SlotData<bool(uint)>(11, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'getLayout'
        QtMocHelpers::SlotData<uint() const>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::UInt),
        // Slot 'getLayoutsList'
        QtMocHelpers::SlotData<QList<LayoutNames>() const>(22, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 23),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KeyboardDaemon, qt_meta_tag_ZN14KeyboardDaemonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KeyboardDaemon::staticMetaObject = { {
    QMetaObject::SuperData::link<KDEDModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KeyboardDaemonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KeyboardDaemonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KeyboardDaemonE_t>.metaTypes,
    nullptr
} };

void KeyboardDaemon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardDaemon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->layoutChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->layoutListChanged(); break;
        case 2: _t->configureKeyboard(); break;
        case 3: _t->configureInput(); break;
        case 4: _t->layoutChangedSlot(); break;
        case 5: _t->layoutMapChanged(); break;
        case 6: { bool _r = _t->setLayout((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->configChanged((*reinterpret_cast<std::add_pointer_t<KConfigGroup>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArrayList>>(_a[2]))); break;
        case 8: _t->switchToNextLayout(); break;
        case 9: _t->switchToPreviousLayout(); break;
        case 10: { bool _r = _t->setLayout((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { uint _r = _t->getLayout();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 12: { QList<LayoutNames> _r = _t->getLayoutsList();
            if (_a[0]) *reinterpret_cast<QList<LayoutNames>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardDaemon::*)(uint )>(_a, &KeyboardDaemon::layoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardDaemon::*)()>(_a, &KeyboardDaemon::layoutListChanged, 1))
            return;
    }
}

const QMetaObject *KeyboardDaemon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardDaemon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KeyboardDaemonE_t>.strings))
        return static_cast<void*>(this);
    return KDEDModule::qt_metacast(_clname);
}

int KeyboardDaemon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDEDModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KeyboardDaemon::layoutChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyboardDaemon::layoutListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
