/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilitykeyboard.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilitykeyboard.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilitykeyboard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KeyboardSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardSettings::qt_create_metaobjectdata<qt_meta_tag_ZN16KeyboardSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardSettings",
        "StickyKeysChanged",
        "",
        "StickyKeysLatchChanged",
        "StickyKeysAutoOffChanged",
        "StickyKeysBeepChanged",
        "ToggleKeysBeepChanged",
        "KeyboardNotifyModifiersChanged",
        "stickyKeys",
        "isStickyKeysImmutable",
        "defaultStickyKeysValue",
        "stickyKeysLatch",
        "isStickyKeysLatchImmutable",
        "defaultStickyKeysLatchValue",
        "stickyKeysAutoOff",
        "isStickyKeysAutoOffImmutable",
        "defaultStickyKeysAutoOffValue",
        "stickyKeysBeep",
        "isStickyKeysBeepImmutable",
        "defaultStickyKeysBeepValue",
        "toggleKeysBeep",
        "isToggleKeysBeepImmutable",
        "defaultToggleKeysBeepValue",
        "keyboardNotifyModifiers",
        "isKeyboardNotifyModifiersImmutable",
        "defaultKeyboardNotifyModifiersValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'StickyKeysChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StickyKeysLatchChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StickyKeysAutoOffChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'StickyKeysBeepChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ToggleKeysBeepChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'KeyboardNotifyModifiersChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'stickyKeys'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isStickyKeysImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStickyKeysValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stickyKeysLatch'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isStickyKeysLatchImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStickyKeysLatchValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stickyKeysAutoOff'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isStickyKeysAutoOffImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStickyKeysAutoOffValue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stickyKeysBeep'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isStickyKeysBeepImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStickyKeysBeepValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'toggleKeysBeep'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isToggleKeysBeepImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultToggleKeysBeepValue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyboardNotifyModifiers'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isKeyboardNotifyModifiersImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeyboardNotifyModifiersValue'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardSettings, qt_meta_tag_ZN16KeyboardSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.metaTypes,
    nullptr
} };

void KeyboardSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->StickyKeysChanged(); break;
        case 1: _t->StickyKeysLatchChanged(); break;
        case 2: _t->StickyKeysAutoOffChanged(); break;
        case 3: _t->StickyKeysBeepChanged(); break;
        case 4: _t->ToggleKeysBeepChanged(); break;
        case 5: _t->KeyboardNotifyModifiersChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::StickyKeysChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::StickyKeysLatchChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::StickyKeysAutoOffChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::StickyKeysBeepChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::ToggleKeysBeepChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardSettings::*)()>(_a, &KeyboardSettings::KeyboardNotifyModifiersChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->stickyKeys(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isStickyKeysImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultStickyKeysValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->stickyKeysLatch(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isStickyKeysLatchImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultStickyKeysLatchValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->stickyKeysAutoOff(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isStickyKeysAutoOffImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultStickyKeysAutoOffValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->stickyKeysBeep(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isStickyKeysBeepImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultStickyKeysBeepValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->toggleKeysBeep(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isToggleKeysBeepImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultToggleKeysBeepValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->keyboardNotifyModifiers(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isKeyboardNotifyModifiersImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultKeyboardNotifyModifiersValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setStickyKeys(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setStickyKeysLatch(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setStickyKeysAutoOff(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setStickyKeysBeep(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setToggleKeysBeep(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setKeyboardNotifyModifiers(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KeyboardSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int KeyboardSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KeyboardSettings::StickyKeysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyboardSettings::StickyKeysLatchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeyboardSettings::StickyKeysAutoOffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyboardSettings::StickyKeysBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyboardSettings::ToggleKeysBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KeyboardSettings::KeyboardNotifyModifiersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
