/****************************************************************************
** Meta object code from reading C++ file 'kcm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/mouse/kcm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7MessageE_t {};
} // unnamed namespace

template <> constexpr inline auto Message::qt_create_metaobjectdata<qt_meta_tag_ZN7MessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Message",
        "text",
        "type",
        "MessageType::MessageType"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'text'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final),
        // property 'type'
        QtMocHelpers::PropertyData<MessageType::MessageType>(2, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Message, qt_meta_tag_ZN7MessageE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN7MessageE[] = {
    QMetaObject::SuperData::link<MessageType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Message::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7MessageE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN7MessageE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7MessageE_t>.metaTypes,
    nullptr
} };

void Message::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Message *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->text; break;
        case 1: *reinterpret_cast<MessageType::MessageType*>(_v) = _t->type; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->text, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->type, *reinterpret_cast<MessageType::MessageType*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN8KCMMouseE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMMouse::qt_create_metaobjectdata<qt_meta_tag_ZN8KCMMouseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMMouse",
        "saveLoadMessageChanged",
        "",
        "hotplugMessageChanged",
        "currentDeviceIndexChanged",
        "load",
        "save",
        "defaults",
        "updateKcmNeedsSave",
        "onDeviceAdded",
        "success",
        "onDeviceRemoved",
        "index",
        "saveLoadMessage",
        "Message",
        "hotplugMessage",
        "inputBackend",
        "InputBackend*",
        "currentDeviceIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'saveLoadMessageChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hotplugMessageChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentDeviceIndexChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateKcmNeedsSave'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'onDeviceRemoved'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'saveLoadMessage'
        QtMocHelpers::PropertyData<Message>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'hotplugMessage'
        QtMocHelpers::PropertyData<Message>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'inputBackend'
        QtMocHelpers::PropertyData<InputBackend*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'currentDeviceIndex'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMMouse, qt_meta_tag_ZN8KCMMouseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMMouse::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KCMMouseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KCMMouseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KCMMouseE_t>.metaTypes,
    nullptr
} };

void KCMMouse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMMouse *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->saveLoadMessageChanged(); break;
        case 1: _t->hotplugMessageChanged(); break;
        case 2: _t->currentDeviceIndexChanged(); break;
        case 3: _t->load(); break;
        case 4: _t->save(); break;
        case 5: _t->defaults(); break;
        case 6: _t->updateKcmNeedsSave(); break;
        case 7: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->onDeviceRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMMouse::*)()>(_a, &KCMMouse::saveLoadMessageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMMouse::*)()>(_a, &KCMMouse::hotplugMessageChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMMouse::*)()>(_a, &KCMMouse::currentDeviceIndexChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Message*>(_v) = _t->m_saveLoadMessage; break;
        case 1: *reinterpret_cast<Message*>(_v) = _t->m_hotplugMessage; break;
        case 2: *reinterpret_cast<InputBackend**>(_v) = _t->inputBackend(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->currentDeviceIndex(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_saveLoadMessage, *reinterpret_cast<Message*>(_v)))
                Q_EMIT _t->saveLoadMessageChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_hotplugMessage, *reinterpret_cast<Message*>(_v)))
                Q_EMIT _t->hotplugMessageChanged();
            break;
        case 3: _t->setCurrentDeviceIndex(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCMMouse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMMouse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KCMMouseE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMMouse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KCMMouse::saveLoadMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMMouse::hotplugMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMMouse::currentDeviceIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN11MessageTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto MessageType::qt_create_metaobjectdata<qt_meta_tag_ZN11MessageTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MessageType",
        "None",
        "Information",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MessageType'
        QtMocHelpers::EnumData<MessageType>(0, 0, QMC::EnumFlags{}).add({
            {    1, MessageType::None },
            {    2, MessageType::Information },
            {    3, MessageType::Error },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11MessageTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN11MessageTypeE =
    MessageType::qt_create_metaobjectdata<qt_meta_tag_ZN11MessageTypeE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11MessageTypeE =
    qt_staticMetaObjectContent_ZN11MessageTypeE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11MessageTypeE =
    qt_staticMetaObjectContent_ZN11MessageTypeE.relocatingData;

Q_CONSTINIT const QMetaObject MessageType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11MessageTypeE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11MessageTypeE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11MessageTypeE.metaTypes,
    nullptr
} };

QT_WARNING_POP
