// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef DEVICEAUTOMOUNTERDATA_H
#define DEVICEAUTOMOUNTERDATA_H

#include <QObject>

#include "kcmoduledata.h"



class AutomounterSettings;


class DeviceAutomounterData : public KCModuleData
{
    Q_OBJECT

public:
    explicit DeviceAutomounterData(QObject *parent = nullptr);
    AutomounterSettings *settings() const;


private:
    AutomounterSettings *m_settings;

};



#endif
