/****************************************************************************
** Meta object code from reading C++ file 'kimpanelagent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/applets/kimpanel/kimpanelagent.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kimpanelagent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PanelAgentE_t {};
} // unnamed namespace

template <> constexpr inline auto PanelAgent::qt_create_metaobjectdata<qt_meta_tag_ZN10PanelAgentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PanelAgent",
        "Configure",
        "",
        "MovePreeditCaret",
        "position",
        "SelectCandidate",
        "index",
        "LookupTablePageUp",
        "LookupTablePageDown",
        "TriggerProperty",
        "key",
        "PanelCreated",
        "PanelCreated2",
        "PanelRegistered",
        "Exit",
        "ReloadConfig",
        "enable",
        "to_enable",
        "updatePreeditCaret",
        "pos",
        "updatePreeditText",
        "text",
        "QList<TextAttribute>",
        "attr",
        "updateAux",
        "updateProperty",
        "KimpanelProperty",
        "prop",
        "updateLookupTable",
        "KimpanelLookupTable",
        "lookup_table",
        "updateLookupTableFull",
        "cursor",
        "layout",
        "updateSpotLocation",
        "x",
        "y",
        "updateSpotRect",
        "w",
        "h",
        "registerProperties",
        "QList<KimpanelProperty>",
        "props",
        "execDialog",
        "execMenu",
        "prop_list",
        "showPreedit",
        "to_show",
        "showAux",
        "showLookupTable",
        "updateLookupTableCursor",
        "UpdateLookupTable",
        "labels",
        "candis",
        "attrlists",
        "has_prev",
        "has_next",
        "UpdatePreeditText",
        "UpdateAux",
        "UpdateScreen",
        "screen_id",
        "UpdateProperty",
        "RegisterProperties",
        "ExecDialog",
        "ExecMenu",
        "entries",
        "SetSpotRect",
        "SetLookupTable",
        "hasPrev",
        "hasNext",
        "serviceUnregistered",
        "service"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Configure'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MovePreeditCaret'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'SelectCandidate'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'LookupTablePageUp'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LookupTablePageDown'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TriggerProperty'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'PanelCreated'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PanelCreated2'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PanelRegistered'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Exit'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ReloadConfig'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enable'
        QtMocHelpers::SignalData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'updatePreeditCaret'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'updatePreeditText'
        QtMocHelpers::SignalData<void(const QString &, const QList<TextAttribute> &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Signal 'updateAux'
        QtMocHelpers::SignalData<void(const QString &, const QList<TextAttribute> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Signal 'updateProperty'
        QtMocHelpers::SignalData<void(const KimpanelProperty &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'updateLookupTable'
        QtMocHelpers::SignalData<void(const KimpanelLookupTable &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Signal 'updateLookupTableFull'
        QtMocHelpers::SignalData<void(const KimpanelLookupTable &, int, int)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
        }}),
        // Signal 'updateSpotLocation'
        QtMocHelpers::SignalData<void(int, int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 }, { QMetaType::Int, 36 },
        }}),
        // Signal 'updateSpotRect'
        QtMocHelpers::SignalData<void(int, int, int, int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 }, { QMetaType::Int, 36 }, { QMetaType::Int, 38 }, { QMetaType::Int, 39 },
        }}),
        // Signal 'registerProperties'
        QtMocHelpers::SignalData<void(const QList<KimpanelProperty> &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Signal 'execDialog'
        QtMocHelpers::SignalData<void(const KimpanelProperty &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'execMenu'
        QtMocHelpers::SignalData<void(const QList<KimpanelProperty> &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 45 },
        }}),
        // Signal 'showPreedit'
        QtMocHelpers::SignalData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Signal 'showAux'
        QtMocHelpers::SignalData<void(bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Signal 'showLookupTable'
        QtMocHelpers::SignalData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Signal 'updateLookupTableCursor'
        QtMocHelpers::SignalData<void(int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'UpdateLookupTable'
        QtMocHelpers::SlotData<void(const QStringList &, const QStringList &, const QStringList &, bool, bool)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 52 }, { QMetaType::QStringList, 53 }, { QMetaType::QStringList, 54 }, { QMetaType::Bool, 55 },
            { QMetaType::Bool, 56 },
        }}),
        // Slot 'UpdatePreeditText'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'UpdateAux'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'UpdateScreen'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 60 },
        }}),
        // Slot 'UpdateProperty'
        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'RegisterProperties'
        QtMocHelpers::SlotData<void(const QStringList &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 42 },
        }}),
        // Slot 'ExecDialog'
        QtMocHelpers::SlotData<void(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'ExecMenu'
        QtMocHelpers::SlotData<void(const QStringList &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 65 },
        }}),
        // Slot 'SetSpotRect'
        QtMocHelpers::SlotData<void(int, int, int, int)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 }, { QMetaType::Int, 36 }, { QMetaType::Int, 38 }, { QMetaType::Int, 39 },
        }}),
        // Slot 'SetLookupTable'
        QtMocHelpers::SlotData<void(const QStringList &, const QStringList &, const QStringList &, bool, bool, int, int)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 52 }, { QMetaType::QStringList, 53 }, { QMetaType::QStringList, 54 }, { QMetaType::Bool, 68 },
            { QMetaType::Bool, 69 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'serviceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 71 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PanelAgent, qt_meta_tag_ZN10PanelAgentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PanelAgent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PanelAgentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PanelAgentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PanelAgentE_t>.metaTypes,
    nullptr
} };

void PanelAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PanelAgent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Configure(); break;
        case 1: _t->MovePreeditCaret((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->SelectCandidate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->LookupTablePageUp(); break;
        case 4: _t->LookupTablePageDown(); break;
        case 5: _t->TriggerProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->PanelCreated(); break;
        case 7: _t->PanelCreated2(); break;
        case 8: _t->PanelRegistered(); break;
        case 9: _t->Exit(); break;
        case 10: _t->ReloadConfig(); break;
        case 11: _t->enable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->updatePreeditCaret((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->updatePreeditText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<TextAttribute>>>(_a[2]))); break;
        case 14: _t->updateAux((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<TextAttribute>>>(_a[2]))); break;
        case 15: _t->updateProperty((*reinterpret_cast<std::add_pointer_t<KimpanelProperty>>(_a[1]))); break;
        case 16: _t->updateLookupTable((*reinterpret_cast<std::add_pointer_t<KimpanelLookupTable>>(_a[1]))); break;
        case 17: _t->updateLookupTableFull((*reinterpret_cast<std::add_pointer_t<KimpanelLookupTable>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 18: _t->updateSpotLocation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 19: _t->updateSpotRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 20: _t->registerProperties((*reinterpret_cast<std::add_pointer_t<QList<KimpanelProperty>>>(_a[1]))); break;
        case 21: _t->execDialog((*reinterpret_cast<std::add_pointer_t<KimpanelProperty>>(_a[1]))); break;
        case 22: _t->execMenu((*reinterpret_cast<std::add_pointer_t<QList<KimpanelProperty>>>(_a[1]))); break;
        case 23: _t->showPreedit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->showAux((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->showLookupTable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->updateLookupTableCursor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->UpdateLookupTable((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 28: _t->UpdatePreeditText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 29: _t->UpdateAux((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: _t->UpdateScreen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->UpdateProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->RegisterProperties((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 33: _t->ExecDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->ExecMenu((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 35: _t->SetSpotRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 36: _t->SetLookupTable((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 37: _t->serviceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::Configure, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(int )>(_a, &PanelAgent::MovePreeditCaret, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(int )>(_a, &PanelAgent::SelectCandidate, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::LookupTablePageUp, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::LookupTablePageDown, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const QString & )>(_a, &PanelAgent::TriggerProperty, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::PanelCreated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::PanelCreated2, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::PanelRegistered, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::Exit, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)()>(_a, &PanelAgent::ReloadConfig, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(bool )>(_a, &PanelAgent::enable, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(int )>(_a, &PanelAgent::updatePreeditCaret, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const QString & , const QList<TextAttribute> & )>(_a, &PanelAgent::updatePreeditText, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const QString & , const QList<TextAttribute> & )>(_a, &PanelAgent::updateAux, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const KimpanelProperty & )>(_a, &PanelAgent::updateProperty, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const KimpanelLookupTable & )>(_a, &PanelAgent::updateLookupTable, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const KimpanelLookupTable & , int , int )>(_a, &PanelAgent::updateLookupTableFull, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(int , int )>(_a, &PanelAgent::updateSpotLocation, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(int , int , int , int )>(_a, &PanelAgent::updateSpotRect, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const QList<KimpanelProperty> & )>(_a, &PanelAgent::registerProperties, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const KimpanelProperty & )>(_a, &PanelAgent::execDialog, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(const QList<KimpanelProperty> & )>(_a, &PanelAgent::execMenu, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(bool )>(_a, &PanelAgent::showPreedit, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(bool )>(_a, &PanelAgent::showAux, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(bool )>(_a, &PanelAgent::showLookupTable, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (PanelAgent::*)(int )>(_a, &PanelAgent::updateLookupTableCursor, 26))
            return;
    }
}

const QMetaObject *PanelAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PanelAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PanelAgentE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int PanelAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void PanelAgent::Configure()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PanelAgent::MovePreeditCaret(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PanelAgent::SelectCandidate(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PanelAgent::LookupTablePageUp()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PanelAgent::LookupTablePageDown()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PanelAgent::TriggerProperty(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PanelAgent::PanelCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PanelAgent::PanelCreated2()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PanelAgent::PanelRegistered()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PanelAgent::Exit()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PanelAgent::ReloadConfig()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PanelAgent::enable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void PanelAgent::updatePreeditCaret(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void PanelAgent::updatePreeditText(const QString & _t1, const QList<TextAttribute> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void PanelAgent::updateAux(const QString & _t1, const QList<TextAttribute> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void PanelAgent::updateProperty(const KimpanelProperty & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void PanelAgent::updateLookupTable(const KimpanelLookupTable & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void PanelAgent::updateLookupTableFull(const KimpanelLookupTable & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void PanelAgent::updateSpotLocation(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1, _t2);
}

// SIGNAL 19
void PanelAgent::updateSpotRect(int _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 20
void PanelAgent::registerProperties(const QList<KimpanelProperty> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void PanelAgent::execDialog(const KimpanelProperty & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void PanelAgent::execMenu(const QList<KimpanelProperty> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void PanelAgent::showPreedit(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void PanelAgent::showAux(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void PanelAgent::showLookupTable(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void PanelAgent::updateLookupTableCursor(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}
QT_WARNING_POP
