/****************************************************************************
** Meta object code from reading C++ file 'kcmtablet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/tablet/kcmtablet.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmtablet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6TabletE_t {};
} // unnamed namespace

template <> constexpr inline auto Tablet::qt_create_metaobjectdata<qt_meta_tag_ZN6TabletE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Tablet",
        "settingsRestored",
        "",
        "syncWithMouseChanged",
        "assignPadButtonMapping",
        "deviceName",
        "button",
        "InputSequence",
        "keySequence",
        "assignPadDialMapping",
        "assignPadRingMapping",
        "group",
        "assignToolButtonMapping",
        "padButtonMapping",
        "padDialMapping",
        "padRingMapping",
        "mode",
        "toolButtonMapping",
        "toSerializedCurve",
        "QPointF",
        "controlPoint1",
        "controlPoint2",
        "fromSerializedCurve",
        "QList<QPointF>",
        "curve",
        "tabletsModel",
        "TabletsModel*",
        "db",
        "WacomDeviceDatabase*",
        "syncWithMouse"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsRestored'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncWithMouseChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'assignPadButtonMapping'
        QtMocHelpers::MethodData<void(const QString &, uint, const InputSequence &)>(4, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Method 'assignPadDialMapping'
        QtMocHelpers::MethodData<void(const QString &, uint, const InputSequence &)>(9, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Method 'assignPadRingMapping'
        QtMocHelpers::MethodData<void(const QString &, uint, uint, const InputSequence &)>(10, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 }, { QMetaType::UInt, 11 }, { 0x80000000 | 7, 8 },
        }}),
        // Method 'assignToolButtonMapping'
        QtMocHelpers::MethodData<void(const QString &, uint, const InputSequence &)>(12, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Method 'padButtonMapping'
        QtMocHelpers::MethodData<InputSequence(const QString &, uint) const>(13, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 },
        }}),
        // Method 'padDialMapping'
        QtMocHelpers::MethodData<InputSequence(const QString &, uint) const>(14, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 },
        }}),
        // Method 'padRingMapping'
        QtMocHelpers::MethodData<InputSequence(const QString &, uint, uint) const>(15, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 }, { QMetaType::UInt, 16 },
        }}),
        // Method 'toolButtonMapping'
        QtMocHelpers::MethodData<InputSequence(const QString &, uint) const>(17, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 7, {{
            { QMetaType::QString, 5 }, { QMetaType::UInt, 6 },
        }}),
        // Method 'toSerializedCurve'
        QtMocHelpers::MethodData<QString(const QPointF &, const QPointF &)>(18, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 19, 21 },
        }}),
        // Method 'fromSerializedCurve'
        QtMocHelpers::MethodData<QList<QPointF>(const QString &)>(22, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 23, {{
            { QMetaType::QString, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tabletsModel'
        QtMocHelpers::PropertyData<TabletsModel*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'db'
        QtMocHelpers::PropertyData<WacomDeviceDatabase*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'syncWithMouse'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Tablet, qt_meta_tag_ZN6TabletE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Tablet::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6TabletE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6TabletE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6TabletE_t>.metaTypes,
    nullptr
} };

void Tablet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Tablet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsRestored(); break;
        case 1: _t->syncWithMouseChanged(); break;
        case 2: _t->assignPadButtonMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<InputSequence>>(_a[3]))); break;
        case 3: _t->assignPadDialMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<InputSequence>>(_a[3]))); break;
        case 4: _t->assignPadRingMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<InputSequence>>(_a[4]))); break;
        case 5: _t->assignToolButtonMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<InputSequence>>(_a[3]))); break;
        case 6: { InputSequence _r = _t->padButtonMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<InputSequence*>(_a[0]) = std::move(_r); }  break;
        case 7: { InputSequence _r = _t->padDialMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<InputSequence*>(_a[0]) = std::move(_r); }  break;
        case 8: { InputSequence _r = _t->padRingMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<InputSequence*>(_a[0]) = std::move(_r); }  break;
        case 9: { InputSequence _r = _t->toolButtonMapping((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<InputSequence*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->toSerializedCurve((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QList<QPointF> _r = _t->fromSerializedCurve((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QPointF>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Tablet::*)()>(_a, &Tablet::settingsRestored, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Tablet::*)()>(_a, &Tablet::syncWithMouseChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TabletsModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TabletsModel**>(_v) = _t->tabletsModel(); break;
        case 1: *reinterpret_cast<WacomDeviceDatabase**>(_v) = _t->db(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->syncWithMouse(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setSyncWithMouse(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Tablet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Tablet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6TabletE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int Tablet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Tablet::settingsRestored()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Tablet::syncWithMouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
