/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilitykeyboardfilters.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilitykeyboardfilters.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilitykeyboardfilters.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23KeyboardFiltersSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardFiltersSettings::qt_create_metaobjectdata<qt_meta_tag_ZN23KeyboardFiltersSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardFiltersSettings",
        "SlowKeysChanged",
        "",
        "SlowKeysDelayChanged",
        "SlowKeysPressBeepChanged",
        "SlowKeysAcceptBeepChanged",
        "SlowKeysRejectBeepChanged",
        "BounceKeysChanged",
        "BounceKeysDelayChanged",
        "BounceKeysRejectBeepChanged",
        "slowKeys",
        "isSlowKeysImmutable",
        "defaultSlowKeysValue",
        "slowKeysDelay",
        "isSlowKeysDelayImmutable",
        "defaultSlowKeysDelayValue",
        "slowKeysPressBeep",
        "isSlowKeysPressBeepImmutable",
        "defaultSlowKeysPressBeepValue",
        "slowKeysAcceptBeep",
        "isSlowKeysAcceptBeepImmutable",
        "defaultSlowKeysAcceptBeepValue",
        "slowKeysRejectBeep",
        "isSlowKeysRejectBeepImmutable",
        "defaultSlowKeysRejectBeepValue",
        "bounceKeys",
        "isBounceKeysImmutable",
        "defaultBounceKeysValue",
        "bounceKeysDelay",
        "isBounceKeysDelayImmutable",
        "defaultBounceKeysDelayValue",
        "bounceKeysRejectBeep",
        "isBounceKeysRejectBeepImmutable",
        "defaultBounceKeysRejectBeepValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'SlowKeysChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SlowKeysDelayChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SlowKeysPressBeepChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SlowKeysAcceptBeepChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SlowKeysRejectBeepChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BounceKeysChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BounceKeysDelayChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BounceKeysRejectBeepChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'slowKeys'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isSlowKeysImmutable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlowKeysValue'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slowKeysDelay'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isSlowKeysDelayImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlowKeysDelayValue'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slowKeysPressBeep'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isSlowKeysPressBeepImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlowKeysPressBeepValue'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slowKeysAcceptBeep'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isSlowKeysAcceptBeepImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlowKeysAcceptBeepValue'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slowKeysRejectBeep'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isSlowKeysRejectBeepImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlowKeysRejectBeepValue'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bounceKeys'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isBounceKeysImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBounceKeysValue'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bounceKeysDelay'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isBounceKeysDelayImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBounceKeysDelayValue'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bounceKeysRejectBeep'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isBounceKeysRejectBeepImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBounceKeysRejectBeepValue'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyboardFiltersSettings, qt_meta_tag_ZN23KeyboardFiltersSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyboardFiltersSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KeyboardFiltersSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KeyboardFiltersSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23KeyboardFiltersSettingsE_t>.metaTypes,
    nullptr
} };

void KeyboardFiltersSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardFiltersSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->SlowKeysChanged(); break;
        case 1: _t->SlowKeysDelayChanged(); break;
        case 2: _t->SlowKeysPressBeepChanged(); break;
        case 3: _t->SlowKeysAcceptBeepChanged(); break;
        case 4: _t->SlowKeysRejectBeepChanged(); break;
        case 5: _t->BounceKeysChanged(); break;
        case 6: _t->BounceKeysDelayChanged(); break;
        case 7: _t->BounceKeysRejectBeepChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::SlowKeysChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::SlowKeysDelayChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::SlowKeysPressBeepChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::SlowKeysAcceptBeepChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::SlowKeysRejectBeepChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::BounceKeysChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::BounceKeysDelayChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardFiltersSettings::*)()>(_a, &KeyboardFiltersSettings::BounceKeysRejectBeepChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->slowKeys(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isSlowKeysImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultSlowKeysValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->slowKeysDelay(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isSlowKeysDelayImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultSlowKeysDelayValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->slowKeysPressBeep(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSlowKeysPressBeepImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultSlowKeysPressBeepValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->slowKeysAcceptBeep(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isSlowKeysAcceptBeepImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultSlowKeysAcceptBeepValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->slowKeysRejectBeep(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isSlowKeysRejectBeepImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultSlowKeysRejectBeepValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->bounceKeys(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isBounceKeysImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultBounceKeysValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->bounceKeysDelay(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isBounceKeysDelayImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultBounceKeysDelayValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->bounceKeysRejectBeep(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isBounceKeysRejectBeepImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultBounceKeysRejectBeepValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSlowKeys(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setSlowKeysDelay(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setSlowKeysPressBeep(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSlowKeysAcceptBeep(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setSlowKeysRejectBeep(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setBounceKeys(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setBounceKeysDelay(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setBounceKeysRejectBeep(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardFiltersSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardFiltersSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KeyboardFiltersSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int KeyboardFiltersSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void KeyboardFiltersSettings::SlowKeysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyboardFiltersSettings::SlowKeysDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeyboardFiltersSettings::SlowKeysPressBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyboardFiltersSettings::SlowKeysAcceptBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyboardFiltersSettings::SlowKeysRejectBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KeyboardFiltersSettings::BounceKeysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KeyboardFiltersSettings::BounceKeysDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KeyboardFiltersSettings::BounceKeysRejectBeepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
