// This file is generated by kconfig_compiler_kf6 from kactivitymanagerd_plugins_settings.kcfg.
// All changes you do to this file will be lost.
#ifndef KACTIVITYMANAGERDPLUGINSSETTINGS_H
#define KACTIVITYMANAGERDPLUGINSSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KActivityManagerdPluginsSettings : public KConfigSkeleton
{
  public:

    KActivityManagerdPluginsSettings( QObject *parent = nullptr );
    ~KActivityManagerdPluginsSettings() override;

    /**
      Set How many months keep the activity history
    */
    void setKeepHistoryFor( int v )
    {
      if (!isKeepHistoryForImmutable())
        mKeepHistoryFor = v;
    }

    /**
      Get How many months keep the activity history
    */
    int keepHistoryFor() const
    {
      return mKeepHistoryFor;
    }

    /**
      Is How many months keep the activity history Immutable
    */
    bool isKeepHistoryForImmutable() const
    {
      return isImmutable( QStringLiteral( "keepHistoryFor" ) );
    }

    /**
      Get How many months keep the activity history default value
    */
    int defaultKeepHistoryForValue() const
    {
        return defaultKeepHistoryForValue_helper();
    }

    /**
      Set blocked-by-default
    */
    void setBlockedByDefault( bool v )
    {
      if (!isBlockedByDefaultImmutable())
        mBlockedByDefault = v;
    }

    /**
      Get blocked-by-default
    */
    bool blockedByDefault() const
    {
      return mBlockedByDefault;
    }

    /**
      Is blocked-by-default Immutable
    */
    bool isBlockedByDefaultImmutable() const
    {
      return isImmutable( QStringLiteral( "blockedByDefault" ) );
    }

    /**
      Get blocked-by-default default value
    */
    bool defaultBlockedByDefaultValue() const
    {
        return defaultBlockedByDefaultValue_helper();
    }

    /**
      Set Which data to keep in activity history
    */
    void setWhatToRemember( int v )
    {
      if (!isWhatToRememberImmutable())
        mWhatToRemember = v;
    }

    /**
      Get Which data to keep in activity history
    */
    int whatToRemember() const
    {
      return mWhatToRemember;
    }

    /**
      Is Which data to keep in activity history Immutable
    */
    bool isWhatToRememberImmutable() const
    {
      return isImmutable( QStringLiteral( "whatToRemember" ) );
    }

    /**
      Get Which data to keep in activity history default value
    */
    int defaultWhatToRememberValue() const
    {
        return defaultWhatToRememberValue_helper();
    }

    /**
      Set List of Applications whose activity history to save
    */
    void setAllowedApplications( const QStringList & v )
    {
      if (!isAllowedApplicationsImmutable())
        mAllowedApplications = v;
    }

    /**
      Get List of Applications whose activity history to save
    */
    QStringList allowedApplications() const
    {
      return mAllowedApplications;
    }

    /**
      Is List of Applications whose activity history to save Immutable
    */
    bool isAllowedApplicationsImmutable() const
    {
      return isImmutable( QStringLiteral( "allowedApplications" ) );
    }

    /**
      Set List of Applications whose activity history not to save
    */
    void setBlockedApplications( const QStringList & v )
    {
      if (!isBlockedApplicationsImmutable())
        mBlockedApplications = v;
    }

    /**
      Get List of Applications whose activity history not to save
    */
    QStringList blockedApplications() const
    {
      return mBlockedApplications;
    }

    /**
      Is List of Applications whose activity history not to save Immutable
    */
    bool isBlockedApplicationsImmutable() const
    {
      return isImmutable( QStringLiteral( "blockedApplications" ) );
    }

  protected:

    // Plugin-org.kde.ActivityManager.Resources.Scoring
    int mKeepHistoryFor;
    int defaultKeepHistoryForValue_helper() const;
    bool mBlockedByDefault;
    bool defaultBlockedByDefaultValue_helper() const;
    int mWhatToRemember;
    int defaultWhatToRememberValue_helper() const;
    QStringList mAllowedApplications;
    QStringList defaultAllowedApplicationsValue_helper() const;
    QStringList mBlockedApplications;
    QStringList defaultBlockedApplicationsValue_helper() const;
};

#endif

