/****************************************************************************
** Meta object code from reading C++ file 'switcherbackend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/imports/activitymanager/switcherbackend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'switcherbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SwitcherBackendE_t {};
} // unnamed namespace

template <> constexpr inline auto SwitcherBackend::qt_create_metaobjectdata<qt_meta_tag_ZN15SwitcherBackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SwitcherBackend",
        "QML.Element",
        "auto",
        "Backend",
        "QML.Singleton",
        "true",
        "showSwitchNotification",
        "",
        "id",
        "name",
        "icon",
        "shouldShowSwitcherChanged",
        "value",
        "init",
        "shouldShowSwitcher",
        "setShouldShowSwitcher",
        "runningActivitiesModel",
        "QAbstractItemModel*",
        "setCurrentActivity",
        "activity",
        "removeActivity",
        "dragContainsWindows",
        "QMimeData*",
        "mimeData",
        "setDropMode",
        "drop",
        "modifiers",
        "QVariant",
        "activityId",
        "dropCopy",
        "dropMove",
        "dropEnabled",
        "toggleActivityManager",
        "keybdSwitchToNextActivity",
        "keybdSwitchToPreviousActivity",
        "keybdSwitchedToAnotherActivity",
        "showActivitySwitcherIfNeeded",
        "onCurrentActivityChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showSwitchNotification'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(6, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'shouldShowSwitcherChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(13, 7, QMC::AccessPublic, QMetaType::Void),
        // Slot 'shouldShowSwitcher'
        QtMocHelpers::SlotData<bool() const>(14, 7, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShouldShowSwitcher'
        QtMocHelpers::SlotData<void(bool)>(15, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'runningActivitiesModel'
        QtMocHelpers::SlotData<QAbstractItemModel *() const>(16, 7, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'setCurrentActivity'
        QtMocHelpers::SlotData<void(const QString &)>(18, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'removeActivity'
        QtMocHelpers::SlotData<void(const QString &)>(20, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'dragContainsWindows'
        QtMocHelpers::SlotData<bool(QMimeData *) const>(21, 7, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setDropMode'
        QtMocHelpers::SlotData<void(bool)>(24, 7, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'drop'
        QtMocHelpers::SlotData<void(QMimeData *, int, const QVariant &)>(25, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::Int, 26 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'dropCopy'
        QtMocHelpers::SlotData<void(QMimeData *, const QVariant &)>(29, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'dropMove'
        QtMocHelpers::SlotData<void(QMimeData *, const QVariant &)>(30, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'dropEnabled'
        QtMocHelpers::SlotData<bool() const>(31, 7, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'toggleActivityManager'
        QtMocHelpers::SlotData<void()>(32, 7, QMC::AccessPublic, QMetaType::Void),
        // Slot 'keybdSwitchToNextActivity'
        QtMocHelpers::SlotData<void()>(33, 7, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'keybdSwitchToPreviousActivity'
        QtMocHelpers::SlotData<void()>(34, 7, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'keybdSwitchedToAnotherActivity'
        QtMocHelpers::SlotData<void()>(35, 7, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showActivitySwitcherIfNeeded'
        QtMocHelpers::SlotData<void()>(36, 7, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCurrentActivityChanged'
        QtMocHelpers::SlotData<void(const QString &)>(37, 7, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shouldShowSwitcher'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'dropEnabled'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    1,    3 },
            {    4,    5 },
    });
    return QtMocHelpers::metaObjectData<SwitcherBackend, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SwitcherBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SwitcherBackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SwitcherBackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SwitcherBackendE_t>.metaTypes,
    nullptr
} };

void SwitcherBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SwitcherBackend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showSwitchNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: _t->shouldShowSwitcherChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->init(); break;
        case 3: { bool _r = _t->shouldShowSwitcher();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setShouldShowSwitcher((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: { QAbstractItemModel* _r = _t->runningActivitiesModel();
            if (_a[0]) *reinterpret_cast<QAbstractItemModel**>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setCurrentActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->removeActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: { bool _r = _t->dragContainsWindows((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setDropMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->drop((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 11: _t->dropCopy((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 12: _t->dropMove((*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 13: { bool _r = _t->dropEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->toggleActivityManager(); break;
        case 15: _t->keybdSwitchToNextActivity(); break;
        case 16: _t->keybdSwitchToPreviousActivity(); break;
        case 17: _t->keybdSwitchedToAnotherActivity(); break;
        case 18: _t->showActivitySwitcherIfNeeded(); break;
        case 19: _t->onCurrentActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMimeData* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMimeData* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMimeData* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMimeData* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SwitcherBackend::*)(const QString & , const QString & , const QString & )>(_a, &SwitcherBackend::showSwitchNotification, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SwitcherBackend::*)(bool )>(_a, &SwitcherBackend::shouldShowSwitcherChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->shouldShowSwitcher(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->dropEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShouldShowSwitcher(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SwitcherBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SwitcherBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SwitcherBackendE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SwitcherBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void SwitcherBackend::showSwitchNotification(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void SwitcherBackend::shouldShowSwitcherChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
