// This file is generated by kconfig_compiler_kf6 from DeviceSettings.kcfg.
// All changes you do to this file will be lost.

#include "DeviceSettings.h"

DeviceSettings::DeviceSettings( KSharedConfig::Ptr config, const QString & udi, QObject *parent )
  : KConfigSkeleton( std::move( config ) )
  , mParamudi(udi)
{
  setParent(parent);
  KConfigGroup cgDevices(this->config(), QStringLiteral( "Devices" ));
  KConfigGroup cgudi = cgDevices.group(QStringLiteral( "%1" ).arg( mParamudi ));
  KConfigSkeleton::ItemString  *itemName;
  itemName = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "LastNameSeen" ), mName );
  itemName->setGroup(cgudi);
  addItem( itemName, QStringLiteral( "name" ) );
  KConfigSkeleton::ItemString  *itemIcon;
  itemIcon = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "Icon" ), mIcon );
  itemIcon->setGroup(cgudi);
  addItem( itemIcon, QStringLiteral( "Icon" ) );
  KConfigSkeleton::ItemBool  *itemIsKnown;
  itemIsKnown = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EverMounted" ), mIsKnown, false );
  itemIsKnown->setGroup(cgudi);
  addItem( itemIsKnown, QStringLiteral( "isKnown" ) );
  KConfigSkeleton::ItemBool  *itemMountOnAttach;
  itemMountOnAttach = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceAttachAutomount" ), mMountOnAttach, false );
  itemMountOnAttach->setGroup(cgudi);
  addItem( itemMountOnAttach, QStringLiteral( "mountOnAttach" ) );
  KConfigSkeleton::ItemBool  *itemMountOnLogin;
  itemMountOnLogin = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceLoginAutomount" ), mMountOnLogin, false );
  itemMountOnLogin->setGroup(cgudi);
  addItem( itemMountOnLogin, QStringLiteral( "mountOnLogin" ) );
  KConfigSkeleton::ItemBool  *itemLastSeenMounted;
  itemLastSeenMounted = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "LastSeenMounted" ), mLastSeenMounted, false );
  itemLastSeenMounted->setGroup(cgudi);
  addItem( itemLastSeenMounted, QStringLiteral( "LastSeenMounted" ) );
  KConfigSkeleton::ItemBool  *itemForceAutomount;
  itemForceAutomount = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceAutomount" ), mForceAutomount, false );
  itemForceAutomount->setGroup(cgudi);
  addItem( itemForceAutomount, QStringLiteral( "ForceAutomount" ) );
}

DeviceSettings::~DeviceSettings()
{
}

