/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilityzoommagnifier.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilityzoommagnifier.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilityzoommagnifier.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ZoomMagnifierSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ZoomMagnifierSettings::qt_create_metaobjectdata<qt_meta_tag_ZN21ZoomMagnifierSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ZoomMagnifierSettings",
        "ZoomChanged",
        "",
        "MagnifierChanged",
        "SharedZoomFactorChanged",
        "ZoomMousePointerChanged",
        "ZoomMouseTrackingChanged",
        "ZoomEnableFocusTrackingChanged",
        "ZoomEnableTextCaretTrackingChanged",
        "ZoomPixelGridZoomChanged",
        "ZoomPointerAxisGestureModifiersChanged",
        "ZoomUsePatternUpscalerChanged",
        "MagnifierWidthChanged",
        "MagnifierHeightChanged",
        "zoom",
        "isZoomImmutable",
        "defaultZoomValue",
        "magnifier",
        "isMagnifierImmutable",
        "defaultMagnifierValue",
        "sharedZoomFactor",
        "isSharedZoomFactorImmutable",
        "defaultSharedZoomFactorValue",
        "zoomMousePointer",
        "isZoomMousePointerImmutable",
        "defaultZoomMousePointerValue",
        "zoomMouseTracking",
        "isZoomMouseTrackingImmutable",
        "defaultZoomMouseTrackingValue",
        "zoomEnableFocusTracking",
        "isZoomEnableFocusTrackingImmutable",
        "defaultZoomEnableFocusTrackingValue",
        "zoomEnableTextCaretTracking",
        "isZoomEnableTextCaretTrackingImmutable",
        "defaultZoomEnableTextCaretTrackingValue",
        "zoomPixelGridZoom",
        "isZoomPixelGridZoomImmutable",
        "defaultZoomPixelGridZoomValue",
        "zoomPointerAxisGestureModifiers",
        "isZoomPointerAxisGestureModifiersImmutable",
        "defaultZoomPointerAxisGestureModifiersValue",
        "zoomUsePatternUpscaler",
        "isZoomUsePatternUpscalerImmutable",
        "defaultZoomUsePatternUpscalerValue",
        "magnifierWidth",
        "isMagnifierWidthImmutable",
        "defaultMagnifierWidthValue",
        "magnifierHeight",
        "isMagnifierHeightImmutable",
        "defaultMagnifierHeightValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ZoomChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagnifierChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SharedZoomFactorChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomMousePointerChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomMouseTrackingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomEnableFocusTrackingChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomEnableTextCaretTrackingChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomPixelGridZoomChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomPointerAxisGestureModifiersChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ZoomUsePatternUpscalerChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagnifierWidthChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MagnifierHeightChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'zoom'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isZoomImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomValue'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magnifier'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isMagnifierImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMagnifierValue'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sharedZoomFactor'
        QtMocHelpers::PropertyData<double>(20, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isSharedZoomFactorImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSharedZoomFactorValue'
        QtMocHelpers::PropertyData<double>(22, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomMousePointer'
        QtMocHelpers::PropertyData<uint>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isZoomMousePointerImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomMousePointerValue'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomMouseTracking'
        QtMocHelpers::PropertyData<uint>(26, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isZoomMouseTrackingImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomMouseTrackingValue'
        QtMocHelpers::PropertyData<uint>(28, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomEnableFocusTracking'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isZoomEnableFocusTrackingImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomEnableFocusTrackingValue'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomEnableTextCaretTracking'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isZoomEnableTextCaretTrackingImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomEnableTextCaretTrackingValue'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomPixelGridZoom'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isZoomPixelGridZoomImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomPixelGridZoomValue'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomPointerAxisGestureModifiers'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isZoomPointerAxisGestureModifiersImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomPointerAxisGestureModifiersValue'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zoomUsePatternUpscaler'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isZoomUsePatternUpscalerImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultZoomUsePatternUpscalerValue'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magnifierWidth'
        QtMocHelpers::PropertyData<uint>(44, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isMagnifierWidthImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMagnifierWidthValue'
        QtMocHelpers::PropertyData<uint>(46, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'magnifierHeight'
        QtMocHelpers::PropertyData<uint>(47, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isMagnifierHeightImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMagnifierHeightValue'
        QtMocHelpers::PropertyData<uint>(49, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ZoomMagnifierSettings, qt_meta_tag_ZN21ZoomMagnifierSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ZoomMagnifierSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ZoomMagnifierSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ZoomMagnifierSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ZoomMagnifierSettingsE_t>.metaTypes,
    nullptr
} };

void ZoomMagnifierSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ZoomMagnifierSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ZoomChanged(); break;
        case 1: _t->MagnifierChanged(); break;
        case 2: _t->SharedZoomFactorChanged(); break;
        case 3: _t->ZoomMousePointerChanged(); break;
        case 4: _t->ZoomMouseTrackingChanged(); break;
        case 5: _t->ZoomEnableFocusTrackingChanged(); break;
        case 6: _t->ZoomEnableTextCaretTrackingChanged(); break;
        case 7: _t->ZoomPixelGridZoomChanged(); break;
        case 8: _t->ZoomPointerAxisGestureModifiersChanged(); break;
        case 9: _t->ZoomUsePatternUpscalerChanged(); break;
        case 10: _t->MagnifierWidthChanged(); break;
        case 11: _t->MagnifierHeightChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::MagnifierChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::SharedZoomFactorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomMousePointerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomMouseTrackingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomEnableFocusTrackingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomEnableTextCaretTrackingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomPixelGridZoomChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomPointerAxisGestureModifiersChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::ZoomUsePatternUpscalerChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::MagnifierWidthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ZoomMagnifierSettings::*)()>(_a, &ZoomMagnifierSettings::MagnifierHeightChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->zoom(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isZoomImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultZoomValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->magnifier(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isMagnifierImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultMagnifierValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->sharedZoomFactor(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSharedZoomFactorImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultSharedZoomFactorValue(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->zoomMousePointer(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isZoomMousePointerImmutable(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->defaultZoomMousePointerValue(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->zoomMouseTracking(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isZoomMouseTrackingImmutable(); break;
        case 14: *reinterpret_cast<uint*>(_v) = _t->defaultZoomMouseTrackingValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->zoomEnableFocusTracking(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isZoomEnableFocusTrackingImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultZoomEnableFocusTrackingValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->zoomEnableTextCaretTracking(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isZoomEnableTextCaretTrackingImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultZoomEnableTextCaretTrackingValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->zoomPixelGridZoom(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isZoomPixelGridZoomImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultZoomPixelGridZoomValue(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->zoomPointerAxisGestureModifiers(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isZoomPointerAxisGestureModifiersImmutable(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->defaultZoomPointerAxisGestureModifiersValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->zoomUsePatternUpscaler(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isZoomUsePatternUpscalerImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultZoomUsePatternUpscalerValue(); break;
        case 30: *reinterpret_cast<uint*>(_v) = _t->magnifierWidth(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isMagnifierWidthImmutable(); break;
        case 32: *reinterpret_cast<uint*>(_v) = _t->defaultMagnifierWidthValue(); break;
        case 33: *reinterpret_cast<uint*>(_v) = _t->magnifierHeight(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isMagnifierHeightImmutable(); break;
        case 35: *reinterpret_cast<uint*>(_v) = _t->defaultMagnifierHeightValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setZoom(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setMagnifier(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setSharedZoomFactor(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setZoomMousePointer(*reinterpret_cast<uint*>(_v)); break;
        case 12: _t->setZoomMouseTracking(*reinterpret_cast<uint*>(_v)); break;
        case 15: _t->setZoomEnableFocusTracking(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setZoomEnableTextCaretTracking(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setZoomPixelGridZoom(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setZoomPointerAxisGestureModifiers(*reinterpret_cast<QString*>(_v)); break;
        case 27: _t->setZoomUsePatternUpscaler(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setMagnifierWidth(*reinterpret_cast<uint*>(_v)); break;
        case 33: _t->setMagnifierHeight(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ZoomMagnifierSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ZoomMagnifierSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ZoomMagnifierSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int ZoomMagnifierSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void ZoomMagnifierSettings::ZoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ZoomMagnifierSettings::MagnifierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ZoomMagnifierSettings::SharedZoomFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ZoomMagnifierSettings::ZoomMousePointerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ZoomMagnifierSettings::ZoomMouseTrackingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ZoomMagnifierSettings::ZoomEnableFocusTrackingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ZoomMagnifierSettings::ZoomEnableTextCaretTrackingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ZoomMagnifierSettings::ZoomPixelGridZoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ZoomMagnifierSettings::ZoomPointerAxisGestureModifiersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ZoomMagnifierSettings::ZoomUsePatternUpscalerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ZoomMagnifierSettings::MagnifierWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ZoomMagnifierSettings::MagnifierHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
