/********************************************************************************
** Form generated from reading UI file 'RecentFiles.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECENTFILES_H
#define UI_RECENTFILES_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtQuickWidgets/QQuickWidget>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_RecentFiles
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *messageWidget;
    QFormLayout *formLayout;
    QLabel *labelKeepHistory;
    QHBoxLayout *horizontalLayout;
    QSpinBox *kcfg_keepHistoryFor;
    QPushButton *buttonClearRecentHistory;
    QGroupBox *kcfg_whatToRemember;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *radioRememberAllApplications;
    QRadioButton *radioDontRememberApplications;
    QRadioButton *radioRememberSpecificApplications;
    QLabel *labelRememberDocuments;
    QQuickWidget *viewExcludeddApplications;
    QHBoxLayout *horizontalLayout_1;
    QCheckBox *kcfg_blockedByDefault;

    void setupUi(QWidget *RecentFiles)
    {
        if (RecentFiles->objectName().isEmpty())
            RecentFiles->setObjectName("RecentFiles");
        RecentFiles->resize(629, 500);
        verticalLayout = new QVBoxLayout(RecentFiles);
        verticalLayout->setObjectName("verticalLayout");
        messageWidget = new KMessageWidget(RecentFiles);
        messageWidget->setObjectName("messageWidget");
        messageWidget->setMessageType(KMessageWidget::Positive);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-ok-apply")));
        messageWidget->setIcon(icon);

        verticalLayout->addWidget(messageWidget);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFormAlignment(Qt::AlignHCenter|Qt::AlignTop);
        labelKeepHistory = new QLabel(RecentFiles);
        labelKeepHistory->setObjectName("labelKeepHistory");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelKeepHistory);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_keepHistoryFor = new QSpinBox(RecentFiles);
        kcfg_keepHistoryFor->setObjectName("kcfg_keepHistoryFor");

        horizontalLayout->addWidget(kcfg_keepHistoryFor);

        buttonClearRecentHistory = new QPushButton(RecentFiles);
        buttonClearRecentHistory->setObjectName("buttonClearRecentHistory");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-clear-history")));
        buttonClearRecentHistory->setIcon(icon1);

        horizontalLayout->addWidget(buttonClearRecentHistory);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        kcfg_whatToRemember = new QGroupBox(RecentFiles);
        kcfg_whatToRemember->setObjectName("kcfg_whatToRemember");
        kcfg_whatToRemember->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(kcfg_whatToRemember);
        verticalLayout_2->setObjectName("verticalLayout_2");
        radioRememberAllApplications = new QRadioButton(kcfg_whatToRemember);
        radioRememberAllApplications->setObjectName("radioRememberAllApplications");
        radioRememberAllApplications->setChecked(true);

        verticalLayout_2->addWidget(radioRememberAllApplications);

        radioDontRememberApplications = new QRadioButton(kcfg_whatToRemember);
        radioDontRememberApplications->setObjectName("radioDontRememberApplications");

        verticalLayout_2->addWidget(radioDontRememberApplications);

        radioRememberSpecificApplications = new QRadioButton(kcfg_whatToRemember);
        radioRememberSpecificApplications->setObjectName("radioRememberSpecificApplications");

        verticalLayout_2->addWidget(radioRememberSpecificApplications);


        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_whatToRemember);

        labelRememberDocuments = new QLabel(RecentFiles);
        labelRememberDocuments->setObjectName("labelRememberDocuments");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelRememberDocuments);


        verticalLayout->addLayout(formLayout);

        viewExcludeddApplications = new QQuickWidget(RecentFiles);
        viewExcludeddApplications->setObjectName("viewExcludeddApplications");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(viewExcludeddApplications->sizePolicy().hasHeightForWidth());
        viewExcludeddApplications->setSizePolicy(sizePolicy);
        viewExcludeddApplications->setMinimumSize(QSize(0, 200));
        viewExcludeddApplications->setResizeMode(QQuickWidget::SizeRootObjectToView);

        verticalLayout->addWidget(viewExcludeddApplications);

        horizontalLayout_1 = new QHBoxLayout();
        horizontalLayout_1->setObjectName("horizontalLayout_1");
        horizontalLayout_1->setContentsMargins(6, -1, -1, -1);
        kcfg_blockedByDefault = new QCheckBox(RecentFiles);
        kcfg_blockedByDefault->setObjectName("kcfg_blockedByDefault");

        horizontalLayout_1->addWidget(kcfg_blockedByDefault);


        verticalLayout->addLayout(horizontalLayout_1);


        retranslateUi(RecentFiles);
        QObject::connect(radioRememberSpecificApplications, &QRadioButton::toggled, kcfg_blockedByDefault, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(RecentFiles);
    } // setupUi

    void retranslateUi(QWidget *RecentFiles)
    {
        messageWidget->setText(tr2i18n("Cleared the activity history.", nullptr));
        labelKeepHistory->setText(tr2i18n("Keep history:", nullptr));
        buttonClearRecentHistory->setText(tr2i18n("Clear History", nullptr));
        kcfg_whatToRemember->setTitle(QString());
        radioRememberAllApplications->setText(tr2i18n("For a&ll applications", nullptr));
        radioDontRememberApplications->setText(tr2i18n("&Do not remember", nullptr));
        radioRememberSpecificApplications->setText(tr2i18n("O&nly for specific applications:", nullptr));
        labelRememberDocuments->setText(tr2i18n("Remember opened documents:", nullptr));
        kcfg_blockedByDefault->setText(tr2i18n("Exclude applications not on the list", nullptr));
        (void)RecentFiles;
    } // retranslateUi

};

namespace Ui {
    class RecentFiles: public Ui_RecentFiles {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RECENTFILES_H

