/****************************************************************************
** Meta object code from reading C++ file 'kcmaccess.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/access/kcmaccess.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccess.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KAccessConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto KAccessConfig::qt_create_metaobjectdata<qt_meta_tag_ZN13KAccessConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAccessConfig",
        "orcaLaunchFeedbackChanged",
        "",
        "bellIsDefaultsChanged",
        "mouseIsDefaultsChanged",
        "keyboardFiltersIsDefaultsChanged",
        "keyboardModifiersIsDefaultsChanged",
        "activationGesturesIsDefaultsChanged",
        "screenReaderIsDefaultsChanged",
        "shakeCursorIsDefaultsChanged",
        "colorblindnessCorrectionIsDefaultsChanged",
        "invertIsDefaultsChanged",
        "zoomMagnifierIsDefaultsChanged",
        "configureKNotify",
        "configureInvertShortcuts",
        "configureZoomMagnifyShortcuts",
        "launchOrcaConfiguration",
        "orcaInstalled",
        "mouseSettings",
        "MouseSettings*",
        "bellSettings",
        "BellSettings*",
        "keyboardSettings",
        "KeyboardSettings*",
        "keyboardFiltersSettings",
        "KeyboardFiltersSettings*",
        "activationGesturesSettings",
        "ActivationGesturesSettings*",
        "screenReaderSettings",
        "ScreenReaderSettings*",
        "shakeCursorSettings",
        "ShakeCursorSettings*",
        "colorblindnessCorrectionSettings",
        "ColorblindnessCorrectionSettings*",
        "invertSettings",
        "InvertSettings*",
        "zoomMagnifierSettings",
        "ZoomMagnifierSettings*",
        "orcaLaunchFeedback",
        "screenReaderInstalled",
        "bellIsDefaults",
        "mouseIsDefaults",
        "keyboardFiltersIsDefaults",
        "keyboardModifiersIsDefaults",
        "activationGesturesIsDefaults",
        "screenReaderIsDefaults",
        "shakeCursorIsDefaults",
        "colorblindnessCorrectionIsDefaults",
        "invertIsDefaults",
        "zoomMagnifierIsDefaults",
        "isPlatformX11"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'orcaLaunchFeedbackChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bellIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mouseIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardFiltersIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardModifiersIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activationGesturesIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenReaderIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shakeCursorIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorblindnessCorrectionIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invertIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomMagnifierIsDefaultsChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'configureKNotify'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'configureInvertShortcuts'
        QtMocHelpers::MethodData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'configureZoomMagnifyShortcuts'
        QtMocHelpers::MethodData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'launchOrcaConfiguration'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'orcaInstalled'
        QtMocHelpers::MethodData<bool()>(17, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mouseSettings'
        QtMocHelpers::PropertyData<MouseSettings*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'bellSettings'
        QtMocHelpers::PropertyData<BellSettings*>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'keyboardSettings'
        QtMocHelpers::PropertyData<KeyboardSettings*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'keyboardFiltersSettings'
        QtMocHelpers::PropertyData<KeyboardFiltersSettings*>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'activationGesturesSettings'
        QtMocHelpers::PropertyData<ActivationGesturesSettings*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'screenReaderSettings'
        QtMocHelpers::PropertyData<ScreenReaderSettings*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'shakeCursorSettings'
        QtMocHelpers::PropertyData<ShakeCursorSettings*>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'colorblindnessCorrectionSettings'
        QtMocHelpers::PropertyData<ColorblindnessCorrectionSettings*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'invertSettings'
        QtMocHelpers::PropertyData<InvertSettings*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'zoomMagnifierSettings'
        QtMocHelpers::PropertyData<ZoomMagnifierSettings*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'orcaLaunchFeedback'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'screenReaderInstalled'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bellIsDefaults'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'mouseIsDefaults'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'keyboardFiltersIsDefaults'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'keyboardModifiersIsDefaults'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'activationGesturesIsDefaults'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'screenReaderIsDefaults'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'shakeCursorIsDefaults'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'colorblindnessCorrectionIsDefaults'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'invertIsDefaults'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'zoomMagnifierIsDefaults'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'isPlatformX11'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KAccessConfig, qt_meta_tag_ZN13KAccessConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAccessConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAccessConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAccessConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KAccessConfigE_t>.metaTypes,
    nullptr
} };

void KAccessConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KAccessConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->orcaLaunchFeedbackChanged(); break;
        case 1: _t->bellIsDefaultsChanged(); break;
        case 2: _t->mouseIsDefaultsChanged(); break;
        case 3: _t->keyboardFiltersIsDefaultsChanged(); break;
        case 4: _t->keyboardModifiersIsDefaultsChanged(); break;
        case 5: _t->activationGesturesIsDefaultsChanged(); break;
        case 6: _t->screenReaderIsDefaultsChanged(); break;
        case 7: _t->shakeCursorIsDefaultsChanged(); break;
        case 8: _t->colorblindnessCorrectionIsDefaultsChanged(); break;
        case 9: _t->invertIsDefaultsChanged(); break;
        case 10: _t->zoomMagnifierIsDefaultsChanged(); break;
        case 11: _t->configureKNotify(); break;
        case 12: _t->configureInvertShortcuts(); break;
        case 13: _t->configureZoomMagnifyShortcuts(); break;
        case 14: _t->launchOrcaConfiguration(); break;
        case 15: { bool _r = _t->orcaInstalled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::orcaLaunchFeedbackChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::bellIsDefaultsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::mouseIsDefaultsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::keyboardFiltersIsDefaultsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::keyboardModifiersIsDefaultsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::activationGesturesIsDefaultsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::screenReaderIsDefaultsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::shakeCursorIsDefaultsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::colorblindnessCorrectionIsDefaultsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::invertIsDefaultsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KAccessConfig::*)()>(_a, &KAccessConfig::zoomMagnifierIsDefaultsChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<MouseSettings**>(_v) = _t->mouseSettings(); break;
        case 1: *reinterpret_cast<BellSettings**>(_v) = _t->bellSettings(); break;
        case 2: *reinterpret_cast<KeyboardSettings**>(_v) = _t->keyboardSettings(); break;
        case 3: *reinterpret_cast<KeyboardFiltersSettings**>(_v) = _t->keyboardFiltersSettings(); break;
        case 4: *reinterpret_cast<ActivationGesturesSettings**>(_v) = _t->activationGesturesSettings(); break;
        case 5: *reinterpret_cast<ScreenReaderSettings**>(_v) = _t->screenReaderSettings(); break;
        case 6: *reinterpret_cast<ShakeCursorSettings**>(_v) = _t->shakeCursorSettings(); break;
        case 7: *reinterpret_cast<ColorblindnessCorrectionSettings**>(_v) = _t->colorblindnessCorrectionSettings(); break;
        case 8: *reinterpret_cast<InvertSettings**>(_v) = _t->invertSettings(); break;
        case 9: *reinterpret_cast<ZoomMagnifierSettings**>(_v) = _t->zoomMagnifierSettings(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->orcaLaunchFeedback(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->m_screenReaderInstalled; break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->bellIsDefaults(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->mouseIsDefaults(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->keyboardFiltersIsDefaults(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->keyboardModifiersIsDefaults(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->activationGesturesIsDefaults(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->screenReaderIsDefaults(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->shakeCursorIsDefaults(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->colorblindnessCorrectionIsDefaults(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->invertIsDefaults(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->zoomMagnifierIsDefaults(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isPlatformX11(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 10: _t->setOrcaLaunchFeedback(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KAccessConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAccessConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KAccessConfigE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KAccessConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void KAccessConfig::orcaLaunchFeedbackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KAccessConfig::bellIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KAccessConfig::mouseIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KAccessConfig::keyboardFiltersIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KAccessConfig::keyboardModifiersIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KAccessConfig::activationGesturesIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KAccessConfig::screenReaderIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KAccessConfig::shakeCursorIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KAccessConfig::colorblindnessCorrectionIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KAccessConfig::invertIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KAccessConfig::zoomMagnifierIsDefaultsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
