// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "workspaceoptionsdata.h"

#include "workspaceoptions_plasmasettings.h"
#include "workspaceoptions_kdeglobalssettings.h"
#include "workspaceoptions_kwinsettings.h"




WorkspaceOptionsData::WorkspaceOptionsData(QObject *parent)
: KCModuleData(parent)
, m_workspaceOptionsPlasmaSettings(new WorkspaceOptionsPlasmaSettings(this))
, m_workspaceOptionsGlobalsSettings(new WorkspaceOptionsGlobalsSettings(this))
, m_workspaceOptionsKwinSettings(new WorkspaceOptionsKwinSettings(this))

{
autoRegisterSkeletons();
}

WorkspaceOptionsPlasmaSettings *WorkspaceOptionsData::workspaceOptionsPlasmaSettings() const
{
    return m_workspaceOptionsPlasmaSettings;
}

WorkspaceOptionsGlobalsSettings *WorkspaceOptionsData::workspaceOptionsGlobalsSettings() const
{
    return m_workspaceOptionsGlobalsSettings;
}

WorkspaceOptionsKwinSettings *WorkspaceOptionsData::workspaceOptionsKwinSettings() const
{
    return m_workspaceOptionsKwinSettings;
}





#include "moc_workspaceoptionsdata.cpp"
