/****************************************************************************
** Meta object code from reading C++ file 'inputdevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/mouse/inputdevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11InputDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto InputDevice::qt_create_metaobjectdata<qt_meta_tag_ZN11InputDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InputDevice",
        "needsSaveChanged",
        "",
        "leftHandedChanged",
        "pointerAccelerationChanged",
        "pointerAccelerationProfileFlatChanged",
        "pointerAccelerationProfileAdaptiveChanged",
        "enabledChanged",
        "middleEmulationChanged",
        "naturalScrollChanged",
        "scrollOnButtonDownChanged",
        "scrollFactorChanged",
        "name",
        "supportsDisableEvents",
        "enabled",
        "supportedButtons",
        "Qt::MouseButtons",
        "supportsLeftHanded",
        "leftHandedEnabledByDefault",
        "leftHanded",
        "supportsMiddleEmulation",
        "middleEmulationEnabledByDefault",
        "middleEmulation",
        "supportsPointerAcceleration",
        "pointerAcceleration",
        "supportsPointerAccelerationProfileFlat",
        "defaultPointerAccelerationProfileFlat",
        "pointerAccelerationProfileFlat",
        "supportsPointerAccelerationProfileAdaptive",
        "defaultPointerAccelerationProfileAdaptive",
        "pointerAccelerationProfileAdaptive",
        "supportsNaturalScroll",
        "naturalScrollEnabledByDefault",
        "naturalScroll",
        "supportsScrollOnButtonDown",
        "scrollOnButtonDownEnabledByDefault",
        "scrollOnButtonDown",
        "scrollFactor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needsSaveChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftHandedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationProfileFlatChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointerAccelerationProfileAdaptiveChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'middleEmulationChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'naturalScrollChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollOnButtonDownChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollFactorChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'supportsDisableEvents'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'supportedButtons'
        QtMocHelpers::PropertyData<Qt::MouseButtons>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant | QMC::Final),
        // property 'supportsLeftHanded'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'leftHandedEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'leftHanded'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'supportsMiddleEmulation'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'middleEmulationEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'middleEmulation'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'supportsPointerAcceleration'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'pointerAcceleration'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'supportsPointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'defaultPointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'pointerAccelerationProfileFlat'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'supportsPointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'defaultPointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'pointerAccelerationProfileAdaptive'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'supportsNaturalScroll'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'naturalScrollEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'naturalScroll'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
        // property 'supportsScrollOnButtonDown'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'scrollOnButtonDownEnabledByDefault'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'scrollOnButtonDown'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8),
        // property 'scrollFactor'
        QtMocHelpers::PropertyData<qreal>(37, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<InputDevice, qt_meta_tag_ZN11InputDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject InputDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11InputDeviceE_t>.metaTypes,
    nullptr
} };

void InputDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InputDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needsSaveChanged(); break;
        case 1: _t->leftHandedChanged(); break;
        case 2: _t->pointerAccelerationChanged(); break;
        case 3: _t->pointerAccelerationProfileFlatChanged(); break;
        case 4: _t->pointerAccelerationProfileAdaptiveChanged(); break;
        case 5: _t->enabledChanged(); break;
        case 6: _t->middleEmulationChanged(); break;
        case 7: _t->naturalScrollChanged(); break;
        case 8: _t->scrollOnButtonDownChanged(); break;
        case 9: _t->scrollFactorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::needsSaveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::leftHandedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::pointerAccelerationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::pointerAccelerationProfileFlatChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::pointerAccelerationProfileAdaptiveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::enabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::middleEmulationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::naturalScrollChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::scrollOnButtonDownChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (InputDevice::*)()>(_a, &InputDevice::scrollFactorChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->supportsDisableEvents(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 3: *reinterpret_cast<Qt::MouseButtons*>(_v) = _t->supportedButtons(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->supportsLeftHanded(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->leftHandedEnabledByDefault(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isLeftHanded(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->supportsMiddleEmulation(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->middleEmulationEnabledByDefault(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isMiddleEmulation(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAcceleration(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->pointerAcceleration(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAccelerationProfileFlat(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->defaultPointerAccelerationProfileFlat(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->pointerAccelerationProfileFlat(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->supportsPointerAccelerationProfileAdaptive(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->defaultPointerAccelerationProfileAdaptive(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->pointerAccelerationProfileAdaptive(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->supportsNaturalScroll(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->naturalScrollEnabledByDefault(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isNaturalScroll(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->supportsScrollOnButtonDown(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->scrollOnButtonDownEnabledByDefault(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isScrollOnButtonDown(); break;
        case 24: *reinterpret_cast<qreal*>(_v) = _t->scrollFactor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLeftHanded(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setMiddleEmulation(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setPointerAcceleration(*reinterpret_cast<qreal*>(_v)); break;
        case 14: _t->setPointerAccelerationProfileFlat(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setPointerAccelerationProfileAdaptive(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setNaturalScroll(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setScrollOnButtonDown(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setScrollFactor(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *InputDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11InputDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InputDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void InputDevice::needsSaveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void InputDevice::leftHandedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void InputDevice::pointerAccelerationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void InputDevice::pointerAccelerationProfileFlatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void InputDevice::pointerAccelerationProfileAdaptiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void InputDevice::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void InputDevice::middleEmulationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void InputDevice::naturalScrollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void InputDevice::scrollOnButtonDownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void InputDevice::scrollFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
