/********************************************************************************
** Form generated from reading UI file 'SolidActions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SOLIDACTIONS_H
#define UI_SOLIDACTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SolidActions
{
public:
    QGridLayout *gridLayout;
    QTreeView *TvActions;
    QGridLayout *GlActions;
    QPushButton *PbDeleteAction;
    QPushButton *PbEditAction;
    QPushButton *PbAddAction;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *SolidActions)
    {
        if (SolidActions->objectName().isEmpty())
            SolidActions->setObjectName("SolidActions");
        SolidActions->resize(553, 384);
        gridLayout = new QGridLayout(SolidActions);
        gridLayout->setObjectName("gridLayout");
        TvActions = new QTreeView(SolidActions);
        TvActions->setObjectName("TvActions");

        gridLayout->addWidget(TvActions, 0, 0, 1, 1);

        GlActions = new QGridLayout();
        GlActions->setObjectName("GlActions");
        PbDeleteAction = new QPushButton(SolidActions);
        PbDeleteAction->setObjectName("PbDeleteAction");

        GlActions->addWidget(PbDeleteAction, 0, 1, 1, 1);

        PbEditAction = new QPushButton(SolidActions);
        PbEditAction->setObjectName("PbEditAction");

        GlActions->addWidget(PbEditAction, 0, 3, 1, 1);

        PbAddAction = new QPushButton(SolidActions);
        PbAddAction->setObjectName("PbAddAction");

        GlActions->addWidget(PbAddAction, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        GlActions->addItem(horizontalSpacer, 0, 2, 1, 1);


        gridLayout->addLayout(GlActions, 1, 0, 1, 1);


        retranslateUi(SolidActions);

        QMetaObject::connectSlotsByName(SolidActions);
    } // setupUi

    void retranslateUi(QWidget *SolidActions)
    {
        PbDeleteAction->setText(tr2i18n("Remove", nullptr));
        PbEditAction->setText(tr2i18n("Edit\342\200\246", nullptr));
        PbAddAction->setText(tr2i18n("Add\342\200\246", nullptr));
        (void)SolidActions;
    } // retranslateUi

};

namespace Ui {
    class SolidActions: public Ui_SolidActions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SOLIDACTIONS_H

