// This file is generated by kconfig_compiler_kf6 from gamecontrolleremulationsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef GAMECONTROLLEREMULATIONSETTINGS_H
#define GAMECONTROLLEREMULATIONSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class GameControllerEmulationSettings : public KConfigSkeleton
{
  public:

    GameControllerEmulationSettings( );
    ~GameControllerEmulationSettings() override;

    /**
      Set gamecontrollerEnabled
    */
    void setGamecontrollerEnabled( bool v )
    {
      if (!isGamecontrollerEnabledImmutable())
        mGamecontrollerEnabled = v;
    }

    /**
      Get gamecontrollerEnabled
    */
    bool gamecontrollerEnabled() const
    {
      return mGamecontrollerEnabled;
    }

    /**
      Is gamecontrollerEnabled Immutable
    */
    bool isGamecontrollerEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "gamecontrollerEnabled" ) );
    }

  protected:

    // Plugins
    bool mGamecontrollerEnabled;
};

#endif

