/****************************************************************************
** Meta object code from reading C++ file 'impaneladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "impaneladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'impaneladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ImpanelAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ImpanelAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14ImpanelAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImpanelAdaptor",
        "D-Bus Interface",
        "org.kde.impanel",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.impanel\">\n    <signal name=\"MovePre"
        "editCaret\">\n      <arg type=\"i\" name=\"position\"/>\n    </sig"
        "nal>\n    <signal name=\"SelectCandidate\">\n      <arg type=\"i\""
        " name=\"index\"/>\n    </signal>\n    <signal name=\"LookupTablePa"
        "geUp\"/>\n    <signal name=\"LookupTablePageDown\"/>\n    <signal "
        "name=\"TriggerProperty\">\n      <arg type=\"s\" name=\"key\"/>\n "
        "   </signal>\n    <signal name=\"PanelCreated\"/>\n    <signal nam"
        "e=\"Exit\"/>\n    <signal name=\"ReloadConfig\"/>\n    <signal nam"
        "e=\"Configure\"/>\n  </interface>\n",
        "Configure",
        "",
        "Exit",
        "LookupTablePageDown",
        "LookupTablePageUp",
        "MovePreeditCaret",
        "position",
        "PanelCreated",
        "ReloadConfig",
        "SelectCandidate",
        "index",
        "TriggerProperty",
        "key"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Configure'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'Exit'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LookupTablePageDown'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LookupTablePageUp'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MovePreeditCaret'
        QtMocHelpers::SignalData<void(int)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Signal 'PanelCreated'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ReloadConfig'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SelectCandidate'
        QtMocHelpers::SignalData<void(int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'TriggerProperty'
        QtMocHelpers::SignalData<void(const QString &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ImpanelAdaptor, qt_meta_tag_ZN14ImpanelAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ImpanelAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ImpanelAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ImpanelAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ImpanelAdaptorE_t>.metaTypes,
    nullptr
} };

void ImpanelAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImpanelAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Configure(); break;
        case 1: _t->Exit(); break;
        case 2: _t->LookupTablePageDown(); break;
        case 3: _t->LookupTablePageUp(); break;
        case 4: _t->MovePreeditCaret((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->PanelCreated(); break;
        case 6: _t->ReloadConfig(); break;
        case 7: _t->SelectCandidate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->TriggerProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)()>(_a, &ImpanelAdaptor::Configure, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)()>(_a, &ImpanelAdaptor::Exit, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)()>(_a, &ImpanelAdaptor::LookupTablePageDown, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)()>(_a, &ImpanelAdaptor::LookupTablePageUp, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)(int )>(_a, &ImpanelAdaptor::MovePreeditCaret, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)()>(_a, &ImpanelAdaptor::PanelCreated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)()>(_a, &ImpanelAdaptor::ReloadConfig, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)(int )>(_a, &ImpanelAdaptor::SelectCandidate, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImpanelAdaptor::*)(const QString & )>(_a, &ImpanelAdaptor::TriggerProperty, 8))
            return;
    }
}

const QMetaObject *ImpanelAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImpanelAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ImpanelAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ImpanelAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ImpanelAdaptor::Configure()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImpanelAdaptor::Exit()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImpanelAdaptor::LookupTablePageDown()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ImpanelAdaptor::LookupTablePageUp()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImpanelAdaptor::MovePreeditCaret(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ImpanelAdaptor::PanelCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ImpanelAdaptor::ReloadConfig()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ImpanelAdaptor::SelectCandidate(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ImpanelAdaptor::TriggerProperty(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN15Impanel2AdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto Impanel2Adaptor::qt_create_metaobjectdata<qt_meta_tag_ZN15Impanel2AdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Impanel2Adaptor",
        "D-Bus Interface",
        "org.kde.impanel2",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.impanel2\">\n    <signal name=\"PanelC"
        "reated2\"/>\n    <method name=\"SetSpotRect\">\n      <arg directi"
        "on=\"in\" type=\"i\" name=\"x\"/>\n      <arg direction=\"in\" typ"
        "e=\"i\" name=\"y\"/>\n      <arg direction=\"in\" type=\"i\" name="
        "\"w\"/>\n      <arg direction=\"in\" type=\"i\" name=\"h\"/>\n    "
        "</method>\n    <method name=\"SetLookupTable\">\n      <arg direct"
        "ion=\"in\" type=\"as\" name=\"label\"/>\n      <arg direction=\"in"
        "\" type=\"as\" name=\"text\"/>\n      <arg direction=\"in\" type=\""
        "as\" name=\"attr\"/>\n      <arg direction=\"in\" type=\"b\" name="
        "\"hasPrev\"/>\n      <arg direction=\"in\" type=\"b\" name=\"hasNe"
        "xt\"/>\n      <arg direction=\"in\" type=\"i\" name=\"cursor\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"layout\"/>\n    </me"
        "thod>\n    <signal name=\"PanelRegistered\"/>\n  </interface>\n",
        "PanelCreated2",
        "",
        "PanelRegistered",
        "SetLookupTable",
        "label",
        "text",
        "attr",
        "hasPrev",
        "hasNext",
        "cursor",
        "layout",
        "SetSpotRect",
        "x",
        "y",
        "w",
        "h"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PanelCreated2'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PanelRegistered'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetLookupTable'
        QtMocHelpers::SlotData<void(const QStringList &, const QStringList &, const QStringList &, bool, bool, int, int)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QStringList, 10 }, { QMetaType::QStringList, 11 }, { QMetaType::Bool, 12 },
            { QMetaType::Bool, 13 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Slot 'SetSpotRect'
        QtMocHelpers::SlotData<void(int, int, int, int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Impanel2Adaptor, qt_meta_tag_ZN15Impanel2AdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Impanel2Adaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15Impanel2AdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15Impanel2AdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15Impanel2AdaptorE_t>.metaTypes,
    nullptr
} };

void Impanel2Adaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Impanel2Adaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PanelCreated2(); break;
        case 1: _t->PanelRegistered(); break;
        case 2: _t->SetLookupTable((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[7]))); break;
        case 3: _t->SetSpotRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Impanel2Adaptor::*)()>(_a, &Impanel2Adaptor::PanelCreated2, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Impanel2Adaptor::*)()>(_a, &Impanel2Adaptor::PanelRegistered, 1))
            return;
    }
}

const QMetaObject *Impanel2Adaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Impanel2Adaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15Impanel2AdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int Impanel2Adaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Impanel2Adaptor::PanelCreated2()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Impanel2Adaptor::PanelRegistered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
