/****************************************************************************
** Meta object code from reading C++ file 'basemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/keys/basemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'basemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9BaseModelE_t {};
} // unnamed namespace

template <> constexpr inline auto BaseModel::qt_create_metaobjectdata<qt_meta_tag_ZN9BaseModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BaseModel",
        "addShortcut",
        "",
        "QModelIndex",
        "index",
        "QKeySequence",
        "shortcut",
        "disableShortcut",
        "changeShortcut",
        "oldShortcut",
        "newShortcut",
        "Roles",
        "SectionRole",
        "ComponentRole",
        "ActionRole",
        "ActiveShortcutsRole",
        "DefaultShortcutsRole",
        "CustomShortcutsRole",
        "CheckedRole",
        "PendingDeletionRole",
        "IsDefaultRole",
        "SupportsMultipleKeysRole",
        "IsRemovableRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'addShortcut'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QKeySequence &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Method 'disableShortcut'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QKeySequence &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Method 'changeShortcut'
        QtMocHelpers::MethodData<void(const QModelIndex &, const QKeySequence &, const QKeySequence &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 9 }, { 0x80000000 | 5, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(11, 11, QMC::EnumFlags{}).add({
            {   12, Roles::SectionRole },
            {   13, Roles::ComponentRole },
            {   14, Roles::ActionRole },
            {   15, Roles::ActiveShortcutsRole },
            {   16, Roles::DefaultShortcutsRole },
            {   17, Roles::CustomShortcutsRole },
            {   18, Roles::CheckedRole },
            {   19, Roles::PendingDeletionRole },
            {   20, Roles::IsDefaultRole },
            {   21, Roles::SupportsMultipleKeysRole },
            {   22, Roles::IsRemovableRole },
        }),
    };
    return QtMocHelpers::metaObjectData<BaseModel, qt_meta_tag_ZN9BaseModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BaseModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BaseModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BaseModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9BaseModelE_t>.metaTypes,
    nullptr
} };

void BaseModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BaseModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addShortcut((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[2]))); break;
        case 1: _t->disableShortcut((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[2]))); break;
        case 2: _t->changeShortcut((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[3]))); break;
        default: ;
        }
    }
}

const QMetaObject *BaseModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BaseModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9BaseModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int BaseModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN11ComponentNSE_t {};
} // unnamed namespace

template <> constexpr inline auto ComponentNS::qt_create_metaobjectdata<qt_meta_tag_ZN11ComponentNSE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComponentNS",
        "ComponentType",
        "Application",
        "Command",
        "SystemService",
        "CommonAction"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ComponentType'
        QtMocHelpers::EnumData<ComponentType>(1, 1, QMC::EnumFlags{}).add({
            {    2, ComponentType::Application },
            {    3, ComponentType::Command },
            {    4, ComponentType::SystemService },
            {    5, ComponentType::CommonAction },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11ComponentNSE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN11ComponentNSE =
    ComponentNS::qt_create_metaobjectdata<qt_meta_tag_ZN11ComponentNSE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11ComponentNSE =
    qt_staticMetaObjectContent_ZN11ComponentNSE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11ComponentNSE =
    qt_staticMetaObjectContent_ZN11ComponentNSE.relocatingData;

Q_CONSTINIT const QMetaObject ComponentNS::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11ComponentNSE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11ComponentNSE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11ComponentNSE.metaTypes,
    nullptr
} };

QT_WARNING_POP
