// This file is generated by kconfig_compiler_kf6 from AutomounterSettingsBase.kcfg.
// All changes you do to this file will be lost.
#ifndef AUTOMOUNTERSETTINGSBASE_H
#define AUTOMOUNTERSETTINGSBASE_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class AutomounterSettingsBase : public KConfigSkeleton
{
  public:

    AutomounterSettingsBase( QObject *parent = nullptr );
    ~AutomounterSettingsBase() override;

    /**
      Set AutomountOnLogin
    */
    void setAutomountOnLogin( bool v )
    {
      if (!isAutomountOnLoginImmutable())
        mAutomountOnLogin = v;
    }

    /**
      Get AutomountOnLogin
    */
    bool automountOnLogin() const
    {
      return mAutomountOnLogin;
    }

    /**
      Is AutomountOnLogin Immutable
    */
    bool isAutomountOnLoginImmutable() const
    {
      return isImmutable( QStringLiteral( "AutomountOnLogin" ) );
    }

    /**
      Set AutomountOnPlugin
    */
    void setAutomountOnPlugin( bool v )
    {
      if (!isAutomountOnPluginImmutable())
        mAutomountOnPlugin = v;
    }

    /**
      Get AutomountOnPlugin
    */
    bool automountOnPlugin() const
    {
      return mAutomountOnPlugin;
    }

    /**
      Is AutomountOnPlugin Immutable
    */
    bool isAutomountOnPluginImmutable() const
    {
      return isImmutable( QStringLiteral( "AutomountOnPlugin" ) );
    }

    /**
      Set AutomountUnknownDevices
    */
    void setAutomountUnknownDevices( bool v )
    {
      if (!isAutomountUnknownDevicesImmutable())
        mAutomountUnknownDevices = v;
    }

    /**
      Get AutomountUnknownDevices
    */
    bool automountUnknownDevices() const
    {
      return mAutomountUnknownDevices;
    }

    /**
      Is AutomountUnknownDevices Immutable
    */
    bool isAutomountUnknownDevicesImmutable() const
    {
      return isImmutable( QStringLiteral( "AutomountUnknownDevices" ) );
    }

    /**
      Set AutomountEnabled
    */
    void setAutomountEnabled( bool v )
    {
      if (!isAutomountEnabledImmutable())
        mAutomountEnabled = v;
    }

    /**
      Get AutomountEnabled
    */
    bool automountEnabled() const
    {
      return mAutomountEnabled;
    }

    /**
      Is AutomountEnabled Immutable
    */
    bool isAutomountEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "AutomountEnabled" ) );
    }

  protected:

    // General
    bool mAutomountOnLogin;
    bool mAutomountOnPlugin;
    bool mAutomountUnknownDevices;
    bool mAutomountEnabled;
};

#endif

