/****************************************************************************
** Meta object code from reading C++ file 'landingpage_kdeglobalssettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../landingpage_kdeglobalssettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'landingpage_kdeglobalssettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto LandingPageGlobalsSettings::qt_create_metaobjectdata<qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LandingPageGlobalsSettings",
        "colorSchemeChanged",
        "",
        "singleClickChanged",
        "automaticLookAndFeelChanged",
        "lookAndFeelPackageChanged",
        "defaultLightLookAndFeelChanged",
        "defaultDarkLookAndFeelChanged",
        "animationDurationFactorChanged",
        "colorScheme",
        "isColorSchemeImmutable",
        "defaultColorSchemeValue",
        "singleClick",
        "isSingleClickImmutable",
        "defaultSingleClickValue",
        "automaticLookAndFeel",
        "isAutomaticLookAndFeelImmutable",
        "defaultAutomaticLookAndFeelValue",
        "lookAndFeelPackage",
        "isLookAndFeelPackageImmutable",
        "defaultLookAndFeelPackageValue",
        "defaultLightLookAndFeel",
        "isDefaultLightLookAndFeelImmutable",
        "defaultDefaultLightLookAndFeelValue",
        "defaultDarkLookAndFeel",
        "isDefaultDarkLookAndFeelImmutable",
        "defaultDefaultDarkLookAndFeelValue",
        "animationDurationFactor",
        "isAnimationDurationFactorImmutable",
        "defaultAnimationDurationFactorValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singleClickChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automaticLookAndFeelChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lookAndFeelPackageChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultLightLookAndFeelChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultDarkLookAndFeelChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animationDurationFactorChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorScheme'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isColorSchemeImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColorSchemeValue'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'singleClick'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isSingleClickImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSingleClickValue'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automaticLookAndFeel'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isAutomaticLookAndFeelImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutomaticLookAndFeelValue'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lookAndFeelPackage'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isLookAndFeelPackageImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLookAndFeelPackageValue'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLightLookAndFeel'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isDefaultLightLookAndFeelImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultLightLookAndFeelValue'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDarkLookAndFeel'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isDefaultDarkLookAndFeelImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultDarkLookAndFeelValue'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'animationDurationFactor'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isAnimationDurationFactorImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAnimationDurationFactorValue'
        QtMocHelpers::PropertyData<double>(29, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LandingPageGlobalsSettings, qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LandingPageGlobalsSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t>.metaTypes,
    nullptr
} };

void LandingPageGlobalsSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LandingPageGlobalsSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorSchemeChanged(); break;
        case 1: _t->singleClickChanged(); break;
        case 2: _t->automaticLookAndFeelChanged(); break;
        case 3: _t->lookAndFeelPackageChanged(); break;
        case 4: _t->defaultLightLookAndFeelChanged(); break;
        case 5: _t->defaultDarkLookAndFeelChanged(); break;
        case 6: _t->animationDurationFactorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::colorSchemeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::singleClickChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::automaticLookAndFeelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::lookAndFeelPackageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::defaultLightLookAndFeelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::defaultDarkLookAndFeelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LandingPageGlobalsSettings::*)()>(_a, &LandingPageGlobalsSettings::animationDurationFactorChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->colorScheme(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isColorSchemeImmutable(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->defaultColorSchemeValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->singleClick(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isSingleClickImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultSingleClickValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->automaticLookAndFeel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isAutomaticLookAndFeelImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultAutomaticLookAndFeelValue(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->lookAndFeelPackage(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isLookAndFeelPackageImmutable(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->defaultLookAndFeelPackageValue(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->defaultLightLookAndFeel(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDefaultLightLookAndFeelImmutable(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->defaultDefaultLightLookAndFeelValue(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->defaultDarkLookAndFeel(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isDefaultDarkLookAndFeelImmutable(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->defaultDefaultDarkLookAndFeelValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->animationDurationFactor(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isAnimationDurationFactorImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultAnimationDurationFactorValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorScheme(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setSingleClick(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setAutomaticLookAndFeel(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setLookAndFeelPackage(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setDefaultLightLookAndFeel(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setDefaultDarkLookAndFeel(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setAnimationDurationFactor(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LandingPageGlobalsSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LandingPageGlobalsSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26LandingPageGlobalsSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int LandingPageGlobalsSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void LandingPageGlobalsSettings::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LandingPageGlobalsSettings::singleClickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LandingPageGlobalsSettings::automaticLookAndFeelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void LandingPageGlobalsSettings::lookAndFeelPackageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LandingPageGlobalsSettings::defaultLightLookAndFeelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void LandingPageGlobalsSettings::defaultDarkLookAndFeelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void LandingPageGlobalsSettings::animationDurationFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
