/********************************************************************************
** Form generated from reading UI file 'kcmqtquicksettingswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KCMQTQUICKSETTINGSWIDGET_H
#define UI_KCMQTQUICKSETTINGSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_KCMQtQuickSettingsWidget
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *kmessagewidget;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *kcfg_SceneGraphBackend;
    QLabel *label_2;
    QLabel *label_3;
    QComboBox *kcfg_RenderLoop;
    QCheckBox *kcfg_ForceGlCoreProfile;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KCMQtQuickSettingsWidget)
    {
        if (KCMQtQuickSettingsWidget->objectName().isEmpty())
            KCMQtQuickSettingsWidget->setObjectName("KCMQtQuickSettingsWidget");
        KCMQtQuickSettingsWidget->resize(687, 333);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KCMQtQuickSettingsWidget->sizePolicy().hasHeightForWidth());
        KCMQtQuickSettingsWidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(KCMQtQuickSettingsWidget);
        verticalLayout->setObjectName("verticalLayout");
        kmessagewidget = new KMessageWidget(KCMQtQuickSettingsWidget);
        kmessagewidget->setObjectName("kmessagewidget");
        kmessagewidget->setWordWrap(true);
        kmessagewidget->setCloseButtonVisible(false);
        kmessagewidget->setMessageType(KMessageWidget::Warning);

        verticalLayout->addWidget(kmessagewidget);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(KCMQtQuickSettingsWidget);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_SceneGraphBackend = new QComboBox(KCMQtQuickSettingsWidget);
        kcfg_SceneGraphBackend->addItem(QString());
        kcfg_SceneGraphBackend->addItem(QString());
        kcfg_SceneGraphBackend->addItem(QString());
        kcfg_SceneGraphBackend->addItem(QString());
        kcfg_SceneGraphBackend->setObjectName("kcfg_SceneGraphBackend");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_SceneGraphBackend);

        label_2 = new QLabel(KCMQtQuickSettingsWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        label_3 = new QLabel(KCMQtQuickSettingsWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_RenderLoop = new QComboBox(KCMQtQuickSettingsWidget);
        kcfg_RenderLoop->addItem(QString());
        kcfg_RenderLoop->addItem(QString());
        kcfg_RenderLoop->addItem(QString());
        kcfg_RenderLoop->setObjectName("kcfg_RenderLoop");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_RenderLoop);

        kcfg_ForceGlCoreProfile = new QCheckBox(KCMQtQuickSettingsWidget);
        kcfg_ForceGlCoreProfile->setObjectName("kcfg_ForceGlCoreProfile");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_ForceGlCoreProfile);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 143, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(KCMQtQuickSettingsWidget);

        QMetaObject::connectSlotsByName(KCMQtQuickSettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *KCMQtQuickSettingsWidget)
    {
        kmessagewidget->setText(tr2i18n("These settings adjust the QtQuick settings used by Plasma. Modifying these settings can break your desktop. Only adjust these settings if you know what you are doing.", nullptr));
        label->setText(tr2i18n("Rendering Backend:", nullptr));
        kcfg_SceneGraphBackend->setItemText(0, tr2i18n("Automatic", nullptr));
        kcfg_SceneGraphBackend->setItemText(1, tr2i18n("Open GL", nullptr));
        kcfg_SceneGraphBackend->setItemText(2, tr2i18n("Software", nullptr));
        kcfg_SceneGraphBackend->setItemText(3, tr2i18n("Vulkan", nullptr));

        label_2->setText(tr2i18n("GL Core Profile:", nullptr));
        label_3->setText(tr2i18n("Render Loop:", nullptr));
        kcfg_RenderLoop->setItemText(0, tr2i18n("Automatic", nullptr));
        kcfg_RenderLoop->setItemText(1, tr2i18n("Basic", nullptr));
        kcfg_RenderLoop->setItemText(2, tr2i18n("Threaded", nullptr));

        kcfg_ForceGlCoreProfile->setText(tr2i18n("Force", nullptr));
        (void)KCMQtQuickSettingsWidget;
    } // retranslateUi

};

namespace Ui {
    class KCMQtQuickSettingsWidget: public Ui_KCMQtQuickSettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KCMQTQUICKSETTINGSWIDGET_H

