// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef WORKSPACEOPTIONSDATA_H
#define WORKSPACEOPTIONSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class WorkspaceOptionsPlasmaSettings;
class WorkspaceOptionsGlobalsSettings;
class WorkspaceOptionsKwinSettings;


class WorkspaceOptionsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit WorkspaceOptionsData(QObject *parent = nullptr);
    WorkspaceOptionsPlasmaSettings *workspaceOptionsPlasmaSettings() const;
WorkspaceOptionsGlobalsSettings *workspaceOptionsGlobalsSettings() const;
WorkspaceOptionsKwinSettings *workspaceOptionsKwinSettings() const;


private:
    WorkspaceOptionsPlasmaSettings *m_workspaceOptionsPlasmaSettings;
WorkspaceOptionsGlobalsSettings *m_workspaceOptionsGlobalsSettings;
WorkspaceOptionsKwinSettings *m_workspaceOptionsKwinSettings;

};



#endif
