/*
    GDK - The GIMP Drawing Kit
    SPDX-FileCopyrightText: 1995-1997 Peter Mattis
    SPDX-FileCopyrightText: 1995-1997 Spencer Kimball
    SPDX-FileCopyrightText: 1995-1997 Josh MacDonald
    SPDX-FileCopyrightText: 2005, 2006, 2007, 2009 GNOME Foundation

    SPDX-License-Identifier: LGPL-2.0-or-later
*/
#pragma once

#include <glib.h>

G_BEGIN_DECLS

guint _gdk_keyval_from_name(const gchar *keyval_name);

G_END_DECLS
