/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilitymouse.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilitymouse.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilitymouse.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MouseSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto MouseSettings::qt_create_metaobjectdata<qt_meta_tag_ZN13MouseSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MouseSettings",
        "MouseKeysChanged",
        "",
        "AccelerationDelayChanged",
        "RepetitionIntervalChanged",
        "AccelerationTimeChanged",
        "MaxSpeedChanged",
        "ProfileCurveChanged",
        "mouseKeys",
        "isMouseKeysImmutable",
        "defaultMouseKeysValue",
        "accelerationDelay",
        "isAccelerationDelayImmutable",
        "defaultAccelerationDelayValue",
        "repetitionInterval",
        "isRepetitionIntervalImmutable",
        "defaultRepetitionIntervalValue",
        "accelerationTime",
        "isAccelerationTimeImmutable",
        "defaultAccelerationTimeValue",
        "maxSpeed",
        "isMaxSpeedImmutable",
        "defaultMaxSpeedValue",
        "profileCurve",
        "isProfileCurveImmutable",
        "defaultProfileCurveValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'MouseKeysChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AccelerationDelayChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RepetitionIntervalChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AccelerationTimeChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'MaxSpeedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProfileCurveChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mouseKeys'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isMouseKeysImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMouseKeysValue'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'accelerationDelay'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isAccelerationDelayImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAccelerationDelayValue'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repetitionInterval'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isRepetitionIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRepetitionIntervalValue'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'accelerationTime'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isAccelerationTimeImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAccelerationTimeValue'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxSpeed'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isMaxSpeedImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaxSpeedValue'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profileCurve'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isProfileCurveImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProfileCurveValue'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MouseSettings, qt_meta_tag_ZN13MouseSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MouseSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MouseSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MouseSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MouseSettingsE_t>.metaTypes,
    nullptr
} };

void MouseSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MouseSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->MouseKeysChanged(); break;
        case 1: _t->AccelerationDelayChanged(); break;
        case 2: _t->RepetitionIntervalChanged(); break;
        case 3: _t->AccelerationTimeChanged(); break;
        case 4: _t->MaxSpeedChanged(); break;
        case 5: _t->ProfileCurveChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MouseSettings::*)()>(_a, &MouseSettings::MouseKeysChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseSettings::*)()>(_a, &MouseSettings::AccelerationDelayChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseSettings::*)()>(_a, &MouseSettings::RepetitionIntervalChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseSettings::*)()>(_a, &MouseSettings::AccelerationTimeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseSettings::*)()>(_a, &MouseSettings::MaxSpeedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MouseSettings::*)()>(_a, &MouseSettings::ProfileCurveChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->mouseKeys(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isMouseKeysImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultMouseKeysValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->accelerationDelay(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isAccelerationDelayImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultAccelerationDelayValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->repetitionInterval(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isRepetitionIntervalImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultRepetitionIntervalValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->accelerationTime(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isAccelerationTimeImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultAccelerationTimeValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->maxSpeed(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isMaxSpeedImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultMaxSpeedValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->profileCurve(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isProfileCurveImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultProfileCurveValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMouseKeys(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setAccelerationDelay(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setRepetitionInterval(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setAccelerationTime(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setMaxSpeed(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setProfileCurve(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MouseSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MouseSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MouseSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int MouseSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void MouseSettings::MouseKeysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MouseSettings::AccelerationDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MouseSettings::RepetitionIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MouseSettings::AccelerationTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MouseSettings::MaxSpeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MouseSettings::ProfileCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
