/********************************************************************************
** Form generated from reading UI file 'dateandtime.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DATEANDTIME_H
#define UI_DATEANDTIME_H

#include <QtCore/QVariant>
#include <QtQuickWidgets/QQuickWidget>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kdatepicker.h"
#include "kseparator.h"

QT_BEGIN_NAMESPACE

class Ui_DateAndTime
{
public:
    QVBoxLayout *verticalLayout_3;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QCheckBox *setDateTimeAuto;
    KSeparator *kseparator;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer1;
    KDatePicker *cal;
    QWidget *timeBox;
    QSpacerItem *horizontalSpacer2;
    QSpacerItem *verticalSpacer;
    QQuickWidget *timezoneViewer;

    void setupUi(QWidget *DateAndTime)
    {
        if (DateAndTime->objectName().isEmpty())
            DateAndTime->setObjectName("DateAndTime");
        DateAndTime->resize(613, 463);
        verticalLayout_3 = new QVBoxLayout(DateAndTime);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(DateAndTime);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(true);
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_2 = new QVBoxLayout(tab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        setDateTimeAuto = new QCheckBox(tab);
        setDateTimeAuto->setObjectName("setDateTimeAuto");

        gridLayout->addWidget(setDateTimeAuto, 0, 0, 1, 2);


        verticalLayout_2->addLayout(gridLayout);

        kseparator = new KSeparator(tab);
        kseparator->setObjectName("kseparator");

        verticalLayout_2->addWidget(kseparator);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer1);

        cal = new KDatePicker(tab);
        cal->setObjectName("cal");
        cal->setEnabled(true);

        horizontalLayout->addWidget(cal);

        timeBox = new QWidget(tab);
        timeBox->setObjectName("timeBox");
        timeBox->setEnabled(true);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(timeBox->sizePolicy().hasHeightForWidth());
        timeBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(timeBox);

        horizontalSpacer2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer2);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        tabWidget->addTab(tab, QString());
        timezoneViewer = new QQuickWidget();
        timezoneViewer->setObjectName("timezoneViewer");
        tabWidget->addTab(timezoneViewer, QString());

        verticalLayout_3->addWidget(tabWidget);


        retranslateUi(DateAndTime);
        QObject::connect(setDateTimeAuto, SIGNAL(toggled(bool)), cal, SLOT(setDisabled(bool)));
        QObject::connect(setDateTimeAuto, &QCheckBox::toggled, timeBox, &QWidget::setDisabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DateAndTime);
    } // setupUi

    void retranslateUi(QWidget *DateAndTime)
    {
        setDateTimeAuto->setText(tr2i18n("Set date and time &automatically", nullptr));
#if QT_CONFIG(whatsthis)
        cal->setWhatsThis(tr2i18n("Here you can change the system date's day of the month, month and year.", nullptr));
#endif // QT_CONFIG(whatsthis)
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Date and Time", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(timezoneViewer), tr2i18n("Time Zone", nullptr));
        (void)DateAndTime;
    } // retranslateUi

};

namespace Ui {
    class DateAndTime: public Ui_DateAndTime {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DATEANDTIME_H

