// /qt/qml/plasma/applet/org/kde/plasma/kicker/HoverBlocker.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_plasma_applet_org_kde_plasma_kicker_HoverBlocker_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x28,0x6,0x0,0x0,0x83,0x17,0x84,0x46,
0x9c,0x67,0xba,0x60,0xac,0x55,0x50,0x6c,
0x56,0xae,0xca,0x61,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x2,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x3,0x0,0x0,
0x4,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x5,0x0,0x0,
0xf0,0x0,0x0,0x0,0x90,0x1,0x0,0x0,
0x0,0x2,0x0,0x0,0x78,0x2,0x0,0x0,
0xe0,0x2,0x0,0x0,0xf0,0x2,0x0,0x0,
0x43,0x0,0x0,0x0,0xd1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0xca,0x2e,0x0,0x74,
0x50,0xa,0x8,0x18,0x7,0x30,0x4,0x1a,
0x7,0x6,0x4c,0x8,0xa,0x18,0x7,0x30,
0xc,0x1a,0x7,0x6,0xd4,0x16,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0x2,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x8,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xca,0x28,0x2,0x18,
0x6,0xd4,0x16,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x64,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x1,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x18,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x2,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xa,0x30,0xc,0xa,
0x42,0x1,0x6,0xe,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1d,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xa,0x30,0x4,0x8,
0x30,0xc,0xe,0x2,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x3,0x0,0x0,0x48,0x3,0x0,0x0,
0x60,0x3,0x0,0x0,0x78,0x3,0x0,0x0,
0x98,0x3,0x0,0x0,0xb8,0x3,0x0,0x0,
0xd8,0x3,0x0,0x0,0x10,0x4,0x0,0x0,
0x38,0x4,0x0,0x0,0x80,0x4,0x0,0x0,
0x98,0x4,0x0,0x0,0xd0,0x4,0x0,0x0,
0xe0,0x4,0x0,0x0,0xf8,0x4,0x0,0x0,
0x10,0x5,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x4d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x41,0x0,
0x72,0x0,0x65,0x0,0x61,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x42,0x0,
0x6c,0x0,0x6f,0x0,0x63,0x0,0x6b,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x4d,0x0,
0x6f,0x0,0x76,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x45,0x0,
0x6e,0x0,0x61,0x0,0x62,0x0,0x6c,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x6f,0x0,0x70,0x0,0x61,0x0,0x67,0x0,
0x61,0x0,0x74,0x0,0x65,0x0,0x43,0x0,
0x6f,0x0,0x6d,0x0,0x70,0x0,0x6f,0x0,
0x73,0x0,0x65,0x0,0x64,0x0,0x45,0x0,
0x76,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x50,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x43,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x50,0x0,
0x6f,0x0,0x73,0x0,0x69,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x6e,0x0,0x43,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x50,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x50,0x0,
0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x73,0x0,0x65,0x0,0x74,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x65,0x0,0x6e,0x0,
0x61,0x0,0x62,0x0,0x6c,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x63,0x0,0x65,0x0,0x70,0x0,0x74,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x65,0x0,0x76,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x28,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x1,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x64,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x64,0x0,0x0,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xdc,0x0,0x0,0x0,0xa,0x0,0x10,0x0,
0xb,0x0,0x50,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0xd,0x0,0x50,0x0,0x9,0x0,0x0,0x0,
0x0,0x2,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x50,0x0,
0x18,0x0,0x0,0x1,0x7,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x12,0x0,0x50,0x0,
0x12,0x0,0x80,0x1,0x6,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x50,0x0,
0x10,0x0,0xe0,0x1,0x5,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x50,0x0,
0xf,0x0,0x30,0x1,0x4,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x30,0x1,
0xd,0x0,0xf0,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onPositionChanged at line 18, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
bool v2_16;
bool v2_1;
bool v2_3;
bool v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(0, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadScopeObjectPropertyLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_UNot
s.v2_3 = !s.v2_1;
{
}
// generate_JumpFalse
if (!s.v2_3) {
    goto label_0;
}
{
}
// generate_LoadTrue
s.v2_6 = true;
{
}
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(4, &s.v2_6, QMetaType::fromType<bool>());
{
}
{
}
// generate_Jump
{
    goto label_1;
}
label_0:;
// generate_LoadFalse
s.v2_16 = false;
{
}
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(12, &s.v2_16, QMetaType::fromType<bool>());
{
}
{
}
label_1:;
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 1, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onPressed at line 24, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 2, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
//  at line 24, column 16
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(a1, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *a1 = (*static_cast<QObject **>(argv[1]));
bool v2_0;
bool v2_3;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadFalse
s.v2_0 = false;
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(12, &s.v2_0, QMetaType::fromType<bool>());
{
}
// generate_LoadFalse
s.v2_3 = false;
{
}
// generate_SetLookup
{
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
while (!aotContext->setObjectLookup(1, s.a1, &s.v2_3)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
aotContext->initSetObjectLookup(1, s.a1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// reset at line 29, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
bool v2_0;
bool v2_3;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadFalse
s.v2_0 = false;
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(4, &s.v2_0, QMetaType::fromType<bool>());
{
}
// generate_LoadTrue
s.v2_3 = true;
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(12, &s.v2_3, QMetaType::fromType<bool>());
{
}
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
