/****************************************************************************
** Meta object code from reading C++ file 'shortcuthelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/keyboard/shortcuthelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'shortcuthelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ShortcutHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto ShortcutHelper::qt_create_metaobjectdata<qt_meta_tag_ZN14ShortcutHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShortcutHelper",
        "alternativeShortcutChanged",
        "",
        "lastUsedShortcutChanged",
        "defaults",
        "load",
        "save",
        "defaultAlternativeShortcut",
        "QKeySequence",
        "defaultLastUsedShortcut",
        "alternativeShortcut",
        "lastUsedShortcut"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'alternativeShortcutChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastUsedShortcutChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'defaultAlternativeShortcut'
        QtMocHelpers::MethodData<QKeySequence()>(7, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Method 'defaultLastUsedShortcut'
        QtMocHelpers::MethodData<QKeySequence()>(9, 2, QMC::AccessPublic, 0x80000000 | 8),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'alternativeShortcut'
        QtMocHelpers::PropertyData<QKeySequence>(10, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'lastUsedShortcut'
        QtMocHelpers::PropertyData<QKeySequence>(11, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShortcutHelper, qt_meta_tag_ZN14ShortcutHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShortcutHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ShortcutHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ShortcutHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ShortcutHelperE_t>.metaTypes,
    nullptr
} };

void ShortcutHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShortcutHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->alternativeShortcutChanged(); break;
        case 1: _t->lastUsedShortcutChanged(); break;
        case 2: _t->defaults(); break;
        case 3: _t->load(); break;
        case 4: _t->save(); break;
        case 5: { QKeySequence _r = _t->defaultAlternativeShortcut();
            if (_a[0]) *reinterpret_cast<QKeySequence*>(_a[0]) = std::move(_r); }  break;
        case 6: { QKeySequence _r = _t->defaultLastUsedShortcut();
            if (_a[0]) *reinterpret_cast<QKeySequence*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShortcutHelper::*)()>(_a, &ShortcutHelper::alternativeShortcutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutHelper::*)()>(_a, &ShortcutHelper::lastUsedShortcutChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QKeySequence*>(_v) = _t->alternativeShortcut(); break;
        case 1: *reinterpret_cast<QKeySequence*>(_v) = _t->lastUsedShortcut(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAlternativeShortcut(*reinterpret_cast<QKeySequence*>(_v)); break;
        case 1: _t->setLastUsedShortcut(*reinterpret_cast<QKeySequence*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ShortcutHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShortcutHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ShortcutHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ShortcutHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ShortcutHelper::alternativeShortcutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ShortcutHelper::lastUsedShortcutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
