// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KCMACCESSIBILITYDATA_H
#define KCMACCESSIBILITYDATA_H

#include <QObject>

#include "kcmoduledata.h"



class BellSettings;
class KeyboardSettings;
class KeyboardFiltersSettings;
class MouseSettings;
class ActivationGesturesSettings;
class ScreenReaderSettings;
class ShakeCursorSettings;
class ColorblindnessCorrectionSettings;
class InvertSettings;
class ZoomMagnifierSettings;


class AccessibilityData : public KCModuleData
{
    Q_OBJECT

public:
    explicit AccessibilityData(QObject *parent = nullptr);
    BellSettings *bellSettings() const;
KeyboardSettings *keyboardSettings() const;
KeyboardFiltersSettings *keyboardFiltersSettings() const;
MouseSettings *mouseSettings() const;
ActivationGesturesSettings *activationGesturesSettings() const;
ScreenReaderSettings *screenReaderSettings() const;
ShakeCursorSettings *shakeCursorSettings() const;
ColorblindnessCorrectionSettings *colorblindnessCorrectionSettings() const;
InvertSettings *invertSettings() const;
ZoomMagnifierSettings *zoomMagnifierSettings() const;


private:
    BellSettings *m_bellSettings;
KeyboardSettings *m_keyboardSettings;
KeyboardFiltersSettings *m_keyboardFiltersSettings;
MouseSettings *m_mouseSettings;
ActivationGesturesSettings *m_activationGesturesSettings;
ScreenReaderSettings *m_screenReaderSettings;
ShakeCursorSettings *m_shakeCursorSettings;
ColorblindnessCorrectionSettings *m_colorblindnessCorrectionSettings;
InvertSettings *m_invertSettings;
ZoomMagnifierSettings *m_zoomMagnifierSettings;

};



#endif
