// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "smserverdata.h"

#include "smserversettings.h"




SMServerData::SMServerData(QObject *parent)
: KCModuleData(parent)
, m_settings(new SMServerSettings(this))

{
autoRegisterSkeletons();
}

SMServerSettings *SMServerData::settings() const
{
    return m_settings;
}





#include "moc_smserverdata.cpp"
