// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#ifndef KRUNNERSETTINGSDATA_H
#define KRUNNERSETTINGSDATA_H

#include <QObject>

#include "kcmoduledata.h"



class KRunnerSettingsBase;


class KRunnerSettingsData : public KCModuleData
{
    Q_OBJECT

public:
    explicit KRunnerSettingsData(QObject *parent = nullptr);
    KRunnerSettingsBase *settings() const;


private:
    KRunnerSettingsBase *m_settings;

};



#endif
