// This file is generated by kconfig_compiler_kf6 from kcmaccessibilityinvert.kcfg.
// All changes you do to this file will be lost.

#include "kcmaccessibilityinvert.h"

InvertSettings::InvertSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kwinrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&InvertSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Plugins" ) );

  KConfigCompilerSignallingItem  *itemInvert;
  KConfigSkeleton::ItemBool  *innerItemInvert;
  innerItemInvert = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "invertEnabled" ), mInvert, false );
  itemInvert = new KConfigCompilerSignallingItem(innerItemInvert, this, notifyFunction, signalInvertChanged);
  itemInvert->setWriteFlags(KConfigBase::Notify);
  addItem( itemInvert, QStringLiteral( "Invert" ) );
}

bool InvertSettings::defaultInvertValue_helper() const
{

  return false;
}

InvertSettings::~InvertSettings()
{
}


void InvertSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalInvertChanged:
    Q_EMIT InvertChanged();
    break;
  }
}
