// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "kactivitiesdata.h"

#include "kactivitymanagerd_plugins_settings.h"




KActivitiesData::KActivitiesData(QObject *parent)
: KCModuleData(parent)
, m_settings(new KActivityManagerdPluginsSettings(this))

{
autoRegisterSkeletons();
}

KActivityManagerdPluginsSettings *KActivitiesData::settings() const
{
    return m_settings;
}





#include "moc_kactivitiesdata.cpp"
