// This file is generated by kconfig_compiler_kf6 from gamecontrolleremulationsettings.kcfg.
// All changes you do to this file will be lost.

#include "gamecontrolleremulationsettings.h"

GameControllerEmulationSettings::GameControllerEmulationSettings( )
  : KConfigSkeleton( QStringLiteral( "kwinrc" ) )
{
  setCurrentGroup( QStringLiteral( "Plugins" ) );

  KConfigSkeleton::ItemBool  *itemGamecontrollerEnabled;
  itemGamecontrollerEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "gamecontrollerEnabled" ), mGamecontrollerEnabled, false );
  addItem( itemGamecontrollerEnabled, QStringLiteral( "gamecontrollerEnabled" ) );
}

GameControllerEmulationSettings::~GameControllerEmulationSettings()
{
}

