/****************************************************************************
** Meta object code from reading C++ file 'device.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/gamecontroller/device.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'device.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6DeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto Device::qt_create_metaobjectdata<qt_meta_tag_ZN6DeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Device",
        "buttonStateChanged",
        "",
        "index",
        "leftAxisChanged",
        "rightAxisChanged",
        "leftTriggerChanged",
        "rightTriggerChanged",
        "hatPositionChanged",
        "connectionTypeChanged",
        "type",
        "controllerType",
        "SDL_GameControllerType",
        "controllerTypeName",
        "connectionType",
        "leftAxis",
        "QVector2D",
        "rightAxis",
        "leftTrigger",
        "rightTrigger",
        "ConnectionType",
        "UnknownType",
        "USBType",
        "BluetoothType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'buttonStateChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'leftAxisChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightAxisChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftTriggerChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightTriggerChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hatPositionChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'connectionTypeChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'type'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'controllerType'
        QtMocHelpers::PropertyData<SDL_GameControllerType>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'controllerTypeName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'connectionType'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'leftAxis'
        QtMocHelpers::PropertyData<QVector2D>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'rightAxis'
        QtMocHelpers::PropertyData<QVector2D>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'leftTrigger'
        QtMocHelpers::PropertyData<float>(18, QMetaType::Float, QMC::DefaultPropertyFlags, 3),
        // property 'rightTrigger'
        QtMocHelpers::PropertyData<float>(19, QMetaType::Float, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ConnectionType'
        QtMocHelpers::EnumData<enum ConnectionType>(20, 20, QMC::EnumFlags{}).add({
            {   21, ConnectionType::UnknownType },
            {   22, ConnectionType::USBType },
            {   23, ConnectionType::BluetoothType },
        }),
    };
    return QtMocHelpers::metaObjectData<Device, qt_meta_tag_ZN6DeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Device::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6DeviceE_t>.metaTypes,
    nullptr
} };

void Device::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Device *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->buttonStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->leftAxisChanged(); break;
        case 2: _t->rightAxisChanged(); break;
        case 3: _t->leftTriggerChanged(); break;
        case 4: _t->rightTriggerChanged(); break;
        case 5: _t->hatPositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->connectionTypeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Device::*)(int )>(_a, &Device::buttonStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)()>(_a, &Device::leftAxisChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)()>(_a, &Device::rightAxisChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)()>(_a, &Device::leftTriggerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)()>(_a, &Device::rightTriggerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(int )>(_a, &Device::hatPositionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)()>(_a, &Device::connectionTypeChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        case 1: *reinterpret_cast<SDL_GameControllerType*>(_v) = _t->controllerType(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->controllerTypeName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->connectionType(); break;
        case 4: *reinterpret_cast<QVector2D*>(_v) = _t->leftAxisValue(); break;
        case 5: *reinterpret_cast<QVector2D*>(_v) = _t->rightAxisValue(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->leftTriggerValue(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->rightTriggerValue(); break;
        default: break;
        }
    }
}

const QMetaObject *Device::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Device::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Device::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Device::buttonStateChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Device::leftAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Device::rightAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Device::leftTriggerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Device::rightTriggerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Device::hatPositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Device::connectionTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
