/****************************************************************************
** Meta object code from reading C++ file 'kwinwaylandtouchpad.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/touchpad/backends/kwin_wayland/kwinwaylandtouchpad.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwinwaylandtouchpad.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KWinWaylandTouchpadE_t {};
} // unnamed namespace

template <> constexpr inline auto KWinWaylandTouchpad::qt_create_metaobjectdata<qt_meta_tag_ZN19KWinWaylandTouchpadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWinWaylandTouchpad",
        "scrollFactorChanged",
        "scrollFactor"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scrollFactor'
        QtMocHelpers::PropertyData<qreal>(2, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0x70000000 | 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KWinWaylandTouchpad, qt_meta_tag_ZN19KWinWaylandTouchpadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWinWaylandTouchpad::staticMetaObject = { {
    QMetaObject::SuperData::link<LibinputCommon::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KWinWaylandTouchpadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KWinWaylandTouchpadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KWinWaylandTouchpadE_t>.metaTypes,
    nullptr
} };

void KWinWaylandTouchpad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWinWaylandTouchpad *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->scrollFactor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScrollFactor(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KWinWaylandTouchpad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWinWaylandTouchpad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KWinWaylandTouchpadE_t>.strings))
        return static_cast<void*>(this);
    return LibinputCommon::qt_metacast(_clname);
}

int KWinWaylandTouchpad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = LibinputCommon::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace CheckNotifySignalValidity_ZN19KWinWaylandTouchpadE {
template<typename T> using has_nullary_scrollFactorChanged = decltype(std::declval<T>().scrollFactorChanged());
template<typename T> using has_unary_scrollFactorChanged = decltype(std::declval<T>().scrollFactorChanged(std::declval<qreal>()));
static_assert(qxp::is_detected_v<has_nullary_scrollFactorChanged, KWinWaylandTouchpad> || qxp::is_detected_v<has_unary_scrollFactorChanged, KWinWaylandTouchpad>,
              "NOTIFY signal scrollFactorChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
