// This file is generated by kconfig_compiler_kf6 from splashscreensettings.kcfg.
// All changes you do to this file will be lost.
#ifndef SPLASHSCREENSETTINGS_H
#define SPLASHSCREENSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <KSharedConfig>
#include <KConfig>
#include <KConfigGroup>

class SplashScreenSettings : public KConfigSkeleton
{
  Q_OBJECT
  public:

    SplashScreenSettings( QObject *parent = nullptr );
    ~SplashScreenSettings() override;

    /**
      Set For future use
    */
    void setEngine( const QString & v )
    {
      if (v != mEngine && !isEngineImmutable()) {
        mEngine = v;
        Q_EMIT engineChanged();
      }
    }

    Q_PROPERTY(QString engine READ engine WRITE setEngine NOTIFY engineChanged)
    Q_PROPERTY(bool isEngineImmutable READ isEngineImmutable CONSTANT)
    Q_PROPERTY(QString defaultEngineValue READ defaultEngineValue CONSTANT)
    /**
      Get For future use
    */
    QString engine() const
    {
      return mEngine;
    }

    /**
      Is For future use Immutable
    */
    bool isEngineImmutable() const
    {
      return isImmutable( QStringLiteral( "engine" ) );
    }

    /**
      Get For future use default value
    */
    QString defaultEngineValue() const
    {
        return defaultEngineValue_helper();
    }

    /**
      Set Name of the current splash theme
    */
    void setTheme( const QString & v )
    {
      if (v != mTheme && !isThemeImmutable()) {
        mTheme = v;
        Q_EMIT themeChanged();
      }
    }

    Q_PROPERTY(QString theme READ theme WRITE setTheme NOTIFY themeChanged)
    Q_PROPERTY(bool isThemeImmutable READ isThemeImmutable CONSTANT)
    Q_PROPERTY(QString defaultThemeValue READ defaultThemeValue CONSTANT)
    /**
      Get Name of the current splash theme
    */
    QString theme() const
    {
      return mTheme;
    }

    /**
      Is Name of the current splash theme Immutable
    */
    bool isThemeImmutable() const
    {
      return isImmutable( QStringLiteral( "theme" ) );
    }

    /**
      Get Name of the current splash theme default value
    */
    QString defaultThemeValue() const
    {
        return defaultThemeValue_helper();
    }


    enum {
      signalEngineChanged = 1,
      signalThemeChanged = 2
    };

  Q_SIGNALS:
    void engineChanged();

    void themeChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:

    // KSplash
    QString mEngine;
    QString defaultEngineValue_helper() const;
    QString mTheme;
    QString defaultThemeValue_helper() const;
};

#endif

