// This file is generated by kconfig_compiler_kf6 from renderer.kcfg.
// All changes you do to this file will be lost.

#include "renderersettings.h"

using namespace PlasmaQtQuickSettings;

RendererSettings::RendererSettings( KSharedConfig::Ptr config )
  : KConfigSkeleton( std::move( config ) )
{
  setCurrentGroup( QStringLiteral( "QtQuickRendererSettings" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesRenderLoop;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("automaticloop");
    valuesRenderLoop.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("basic");
    valuesRenderLoop.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("threaded");
    valuesRenderLoop.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemRenderLoop;
  itemRenderLoop = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "RenderLoop" ), mRenderLoop, valuesRenderLoop, automaticloop );
  addItem( itemRenderLoop, QStringLiteral( "RenderLoop" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesSceneGraphBackend;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("automaticbackend");
    valuesSceneGraphBackend.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("opengl");
    valuesSceneGraphBackend.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("software");
    valuesSceneGraphBackend.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("vulkan");
    valuesSceneGraphBackend.append( choice );
  }
  KConfigSkeleton::ItemEnum  *itemSceneGraphBackend;
  itemSceneGraphBackend = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "SceneGraphBackend" ), mSceneGraphBackend, valuesSceneGraphBackend, automaticbackend );
  addItem( itemSceneGraphBackend, QStringLiteral( "SceneGraphBackend" ) );
  KConfigSkeleton::ItemBool  *itemForceGlCoreProfile;
  itemForceGlCoreProfile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ForceGlCoreProfile" ), mForceGlCoreProfile, false );
  addItem( itemForceGlCoreProfile, QStringLiteral( "ForceGlCoreProfile" ) );
}

RendererSettings::~RendererSettings()
{
}

