/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kded6.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KDED_INTERFACE_H
#define KDED_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kded6
 */
class OrgKdeKded6Interface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kded6"; }

public:
    OrgKdeKded6Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKded6Interface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> isModuleAutoloaded(const QString &module)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(module);
        return asyncCallWithArgumentList(QStringLiteral("isModuleAutoloaded"), argumentList);
    }

    inline QDBusPendingReply<bool> isModuleLoadedOnDemand(const QString &module)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(module);
        return asyncCallWithArgumentList(QStringLiteral("isModuleLoadedOnDemand"), argumentList);
    }

    inline QDBusPendingReply<bool> loadModule(const QString &obj)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(obj);
        return asyncCallWithArgumentList(QStringLiteral("loadModule"), argumentList);
    }

    inline QDBusPendingReply<QStringList> loadedModules()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("loadedModules"), argumentList);
    }

    inline QDBusPendingReply<> quit()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("quit"), argumentList);
    }

    inline QDBusPendingReply<> reconfigure()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("reconfigure"), argumentList);
    }

    inline QDBusPendingReply<> registerWindowId(qlonglong windowId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(windowId);
        return asyncCallWithArgumentList(QStringLiteral("registerWindowId"), argumentList);
    }

    inline QDBusPendingReply<> setModuleAutoloading(const QString &module, bool autoload)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(module) << QVariant::fromValue(autoload);
        return asyncCallWithArgumentList(QStringLiteral("setModuleAutoloading"), argumentList);
    }

    inline QDBusPendingReply<bool> unloadModule(const QString &obj)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(obj);
        return asyncCallWithArgumentList(QStringLiteral("unloadModule"), argumentList);
    }

    inline QDBusPendingReply<> unregisterWindowId(qlonglong windowId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(windowId);
        return asyncCallWithArgumentList(QStringLiteral("unregisterWindowId"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    using kded6 = ::OrgKdeKded6Interface;
  }
}

#endif
