/****************************************************************************
** Meta object code from reading C++ file 'kcmaccessibilitycolorblindnesscorrection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kcmaccessibilitycolorblindnesscorrection.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmaccessibilitycolorblindnesscorrection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorblindnessCorrectionSettings::qt_create_metaobjectdata<qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorblindnessCorrectionSettings",
        "ColorblindnessCorrectionChanged",
        "",
        "ModeChanged",
        "IntensityChanged",
        "colorblindnessCorrection",
        "isColorblindnessCorrectionImmutable",
        "defaultColorblindnessCorrectionValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "intensity",
        "isIntensityImmutable",
        "defaultIntensityValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ColorblindnessCorrectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ModeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'IntensityChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorblindnessCorrection'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isColorblindnessCorrectionImmutable'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColorblindnessCorrectionValue'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<uint>(8, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<uint>(10, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensity'
        QtMocHelpers::PropertyData<double>(11, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isIntensityImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityValue'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorblindnessCorrectionSettings, qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorblindnessCorrectionSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t>.metaTypes,
    nullptr
} };

void ColorblindnessCorrectionSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorblindnessCorrectionSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ColorblindnessCorrectionChanged(); break;
        case 1: _t->ModeChanged(); break;
        case 2: _t->IntensityChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ColorblindnessCorrectionSettings::*)()>(_a, &ColorblindnessCorrectionSettings::ColorblindnessCorrectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColorblindnessCorrectionSettings::*)()>(_a, &ColorblindnessCorrectionSettings::ModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ColorblindnessCorrectionSettings::*)()>(_a, &ColorblindnessCorrectionSettings::IntensityChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->colorblindnessCorrection(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isColorblindnessCorrectionImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultColorblindnessCorrectionValue(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->mode(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->defaultModeValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->intensity(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isIntensityImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultIntensityValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorblindnessCorrection(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setMode(*reinterpret_cast<uint*>(_v)); break;
        case 6: _t->setIntensity(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ColorblindnessCorrectionSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorblindnessCorrectionSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32ColorblindnessCorrectionSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int ColorblindnessCorrectionSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ColorblindnessCorrectionSettings::ColorblindnessCorrectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ColorblindnessCorrectionSettings::ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ColorblindnessCorrectionSettings::IntensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
