// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "desktoppathsdata.h"

#include "desktoppathssettings.h"




DesktopPathsData::DesktopPathsData(QObject *parent)
: KCModuleData(parent)
, m_settings(new DesktopPathsSettings(this))

{
autoRegisterSkeletons();
}

DesktopPathsSettings *DesktopPathsData::settings() const
{
    return m_settings;
}





#include "moc_desktoppathsdata.cpp"
