// This file was generated by kcmutils_generate_module_data(): DO NOT EDIT!

#include "kcmaccessibilitydata.h"

#include "kcmaccessibilitybell.h"
#include "kcmaccessibilitykeyboard.h"
#include "kcmaccessibilitykeyboardfilters.h"
#include "kcmaccessibilitymouse.h"
#include "kcmaccessibilityactivationgestures.h"
#include "kcmaccessibilityscreenreader.h"
#include "kcmaccessibilityshakecursor.h"
#include "kcmaccessibilitycolorblindnesscorrection.h"
#include "kcmaccessibilityinvert.h"
#include "kcmaccessibilityzoommagnifier.h"




AccessibilityData::AccessibilityData(QObject *parent)
: KCModuleData(parent)
, m_bellSettings(new BellSettings(this))
, m_keyboardSettings(new KeyboardSettings(this))
, m_keyboardFiltersSettings(new KeyboardFiltersSettings(this))
, m_mouseSettings(new MouseSettings(this))
, m_activationGesturesSettings(new ActivationGesturesSettings(this))
, m_screenReaderSettings(new ScreenReaderSettings(this))
, m_shakeCursorSettings(new ShakeCursorSettings(this))
, m_colorblindnessCorrectionSettings(new ColorblindnessCorrectionSettings(this))
, m_invertSettings(new InvertSettings(this))
, m_zoomMagnifierSettings(new ZoomMagnifierSettings(this))

{
autoRegisterSkeletons();
}

BellSettings *AccessibilityData::bellSettings() const
{
    return m_bellSettings;
}

KeyboardSettings *AccessibilityData::keyboardSettings() const
{
    return m_keyboardSettings;
}

KeyboardFiltersSettings *AccessibilityData::keyboardFiltersSettings() const
{
    return m_keyboardFiltersSettings;
}

MouseSettings *AccessibilityData::mouseSettings() const
{
    return m_mouseSettings;
}

ActivationGesturesSettings *AccessibilityData::activationGesturesSettings() const
{
    return m_activationGesturesSettings;
}

ScreenReaderSettings *AccessibilityData::screenReaderSettings() const
{
    return m_screenReaderSettings;
}

ShakeCursorSettings *AccessibilityData::shakeCursorSettings() const
{
    return m_shakeCursorSettings;
}

ColorblindnessCorrectionSettings *AccessibilityData::colorblindnessCorrectionSettings() const
{
    return m_colorblindnessCorrectionSettings;
}

InvertSettings *AccessibilityData::invertSettings() const
{
    return m_invertSettings;
}

ZoomMagnifierSettings *AccessibilityData::zoomMagnifierSettings() const
{
    return m_zoomMagnifierSettings;
}





#include "moc_kcmaccessibilitydata.cpp"
