/********************************************************************************
** Form generated from reading UI file 'knetattach.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KNETATTACH_H
#define UI_KNETATTACH_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWizard>
#include <QtWidgets/QWizardPage>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_KNetAttach
{
public:
    QWizardPage *_folderType;
    QVBoxLayout *verticalLayout;
    QLabel *textLabel1_2;
    QSpacerItem *spacer20;
    QGroupBox *buttonGroup1;
    QGridLayout *gridLayout;
    QRadioButton *_recent;
    QRadioButton *_webfolder;
    QRadioButton *_fish;
    KComboBox *_recentConnectionName;
    QRadioButton *_ftp;
    QRadioButton *_smb;
    QSpacerItem *spacer2_2;
    QWizardPage *_folderParameters;
    QGridLayout *gridLayout2;
    QLabel *_informationText;
    QSpacerItem *spacer20_2;
    QLabel *textLabel4_2;
    KLineEdit *_connectionName;
    QLabel *_userText;
    KLineEdit *_user;
    QLabel *textLabel1;
    KLineEdit *_host;
    QLabel *_portText;
    QSpinBox *_port;
    QLabel *_protocol;
    KComboBox *_protocolText;
    QLabel *textLabel3;
    KLineEdit *_path;
    QLabel *_encodingText;
    KComboBox *_encoding;
    QCheckBox *_createIcon;
    QCheckBox *_useEncryption;
    QSpacerItem *spacer5;

    void setupUi(QWizard *KNetAttach)
    {
        if (KNetAttach->objectName().isEmpty())
            KNetAttach->setObjectName("KNetAttach");
        KNetAttach->resize(722, 475);
        _folderType = new QWizardPage();
        _folderType->setObjectName("_folderType");
        verticalLayout = new QVBoxLayout(_folderType);
        verticalLayout->setObjectName("verticalLayout");
        textLabel1_2 = new QLabel(_folderType);
        textLabel1_2->setObjectName("textLabel1_2");
        textLabel1_2->setAlignment(Qt::AlignVCenter);
        textLabel1_2->setWordWrap(false);

        verticalLayout->addWidget(textLabel1_2);

        spacer20 = new QSpacerItem(653, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(spacer20);

        buttonGroup1 = new QGroupBox(_folderType);
        buttonGroup1->setObjectName("buttonGroup1");
        buttonGroup1->setFlat(true);
        gridLayout = new QGridLayout(buttonGroup1);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        _recent = new QRadioButton(buttonGroup1);
        _recent->setObjectName("_recent");

        gridLayout->addWidget(_recent, 4, 0, 1, 1);

        _webfolder = new QRadioButton(buttonGroup1);
        _webfolder->setObjectName("_webfolder");
        _webfolder->setChecked(true);

        gridLayout->addWidget(_webfolder, 0, 0, 1, 2);

        _fish = new QRadioButton(buttonGroup1);
        _fish->setObjectName("_fish");
        _fish->setChecked(false);

        gridLayout->addWidget(_fish, 3, 0, 1, 2);

        _recentConnectionName = new KComboBox(buttonGroup1);
        _recentConnectionName->setObjectName("_recentConnectionName");
        _recentConnectionName->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_recentConnectionName->sizePolicy().hasHeightForWidth());
        _recentConnectionName->setSizePolicy(sizePolicy);
        _recentConnectionName->setMinimumSize(QSize(250, 0));

        gridLayout->addWidget(_recentConnectionName, 4, 1, 1, 1);

        _ftp = new QRadioButton(buttonGroup1);
        _ftp->setObjectName("_ftp");

        gridLayout->addWidget(_ftp, 1, 0, 1, 2);

        _smb = new QRadioButton(buttonGroup1);
        _smb->setObjectName("_smb");

        gridLayout->addWidget(_smb, 2, 0, 1, 2);


        verticalLayout->addWidget(buttonGroup1);

        spacer2_2 = new QSpacerItem(653, 184, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacer2_2);

        KNetAttach->addPage(_folderType);
        _folderParameters = new QWizardPage();
        _folderParameters->setObjectName("_folderParameters");
        gridLayout2 = new QGridLayout(_folderParameters);
        gridLayout2->setObjectName("gridLayout2");
        _informationText = new QLabel(_folderParameters);
        _informationText->setObjectName("_informationText");
        _informationText->setAlignment(Qt::AlignVCenter);
        _informationText->setWordWrap(true);

        gridLayout2->addWidget(_informationText, 0, 0, 1, 3);

        spacer20_2 = new QSpacerItem(282, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout2->addItem(spacer20_2, 1, 2, 1, 1);

        textLabel4_2 = new QLabel(_folderParameters);
        textLabel4_2->setObjectName("textLabel4_2");
        textLabel4_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel4_2->setWordWrap(false);

        gridLayout2->addWidget(textLabel4_2, 2, 0, 1, 1);

        _connectionName = new KLineEdit(_folderParameters);
        _connectionName->setObjectName("_connectionName");

        gridLayout2->addWidget(_connectionName, 2, 1, 1, 2);

        _userText = new QLabel(_folderParameters);
        _userText->setObjectName("_userText");
        _userText->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        _userText->setWordWrap(false);

        gridLayout2->addWidget(_userText, 3, 0, 1, 1);

        _user = new KLineEdit(_folderParameters);
        _user->setObjectName("_user");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(10);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(_user->sizePolicy().hasHeightForWidth());
        _user->setSizePolicy(sizePolicy1);

        gridLayout2->addWidget(_user, 3, 1, 1, 2);

        textLabel1 = new QLabel(_folderParameters);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel1->setWordWrap(false);

        gridLayout2->addWidget(textLabel1, 4, 0, 1, 1);

        _host = new KLineEdit(_folderParameters);
        _host->setObjectName("_host");
        sizePolicy1.setHeightForWidth(_host->sizePolicy().hasHeightForWidth());
        _host->setSizePolicy(sizePolicy1);

        gridLayout2->addWidget(_host, 4, 1, 1, 2);

        _portText = new QLabel(_folderParameters);
        _portText->setObjectName("_portText");
        _portText->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        _portText->setWordWrap(false);

        gridLayout2->addWidget(_portText, 5, 0, 1, 1);

        _port = new QSpinBox(_folderParameters);
        _port->setObjectName("_port");
        sizePolicy.setHeightForWidth(_port->sizePolicy().hasHeightForWidth());
        _port->setSizePolicy(sizePolicy);
        _port->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        _port->setMinimum(1);
        _port->setMaximum(65535);

        gridLayout2->addWidget(_port, 5, 1, 1, 1);

        _protocol = new QLabel(_folderParameters);
        _protocol->setObjectName("_protocol");
        _protocol->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        _protocol->setWordWrap(false);

        gridLayout2->addWidget(_protocol, 6, 0, 1, 1);

        _protocolText = new KComboBox(_folderParameters);
        _protocolText->addItem(QString::fromUtf8("sftp"));
        _protocolText->addItem(QString::fromUtf8("fish"));
        _protocolText->setObjectName("_protocolText");

        gridLayout2->addWidget(_protocolText, 6, 1, 1, 1);

        textLabel3 = new QLabel(_folderParameters);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        textLabel3->setWordWrap(false);

        gridLayout2->addWidget(textLabel3, 7, 0, 1, 1);

        _path = new KLineEdit(_folderParameters);
        _path->setObjectName("_path");

        gridLayout2->addWidget(_path, 7, 1, 1, 2);

        _encodingText = new QLabel(_folderParameters);
        _encodingText->setObjectName("_encodingText");
        _encodingText->setEnabled(true);
        _encodingText->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(_encodingText, 8, 0, 1, 1);

        _encoding = new KComboBox(_folderParameters);
        _encoding->setObjectName("_encoding");

        gridLayout2->addWidget(_encoding, 8, 1, 1, 1);

        _createIcon = new QCheckBox(_folderParameters);
        _createIcon->setObjectName("_createIcon");
        _createIcon->setChecked(true);

        gridLayout2->addWidget(_createIcon, 9, 1, 1, 2);

        _useEncryption = new QCheckBox(_folderParameters);
        _useEncryption->setObjectName("_useEncryption");

        gridLayout2->addWidget(_useEncryption, 10, 1, 1, 1);

        spacer5 = new QSpacerItem(653, 56, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout2->addItem(spacer5, 11, 0, 1, 3);

        KNetAttach->addPage(_folderParameters);
#if QT_CONFIG(shortcut)
        textLabel4_2->setBuddy(_connectionName);
        _userText->setBuddy(_user);
        textLabel1->setBuddy(_host);
        _portText->setBuddy(_port);
        _protocol->setBuddy(_port);
        textLabel3->setBuddy(_path);
        _encodingText->setBuddy(_encoding);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KNetAttach);

        QMetaObject::connectSlotsByName(KNetAttach);
    } // setupUi

    void retranslateUi(QWizard *KNetAttach)
    {
        KNetAttach->setWindowTitle(tr2i18n("Network Folder Wizard", nullptr));
        _folderType->setTitle(tr2i18n("Add Network Folder", nullptr));
        textLabel1_2->setText(tr2i18n("Select the type of network folder you wish to connect to and press the Next button.", nullptr));
        buttonGroup1->setTitle(QString());
        _recent->setText(tr2i18n("&Recent connection:", nullptr));
        _webfolder->setText(tr2i18n("&WebFolder (webdav)", nullptr));
        _fish->setText(tr2i18n("&Secure shell (ssh)", nullptr));
        _ftp->setText(tr2i18n("FT&P", nullptr));
        _smb->setText(tr2i18n("&Microsoft\302\256 Windows\302\256 network drive", nullptr));
        _folderParameters->setTitle(tr2i18n("Network Folder Information", nullptr));
        textLabel4_2->setText(tr2i18n("&Name:", nullptr));
        _userText->setText(tr2i18n("&User:", nullptr));
        textLabel1->setText(tr2i18n("Se&rver:", nullptr));
        _portText->setText(tr2i18n("&Port:", nullptr));
        _protocol->setText(tr2i18n("&Protocol:", nullptr));

        textLabel3->setText(tr2i18n("&Folder:", nullptr));
        _encodingText->setText(tr2i18n("Encoding:", nullptr));
        _createIcon->setText(tr2i18n("Cr&eate an icon for this remote folder", nullptr));
        _useEncryption->setText(tr2i18n("&Use encryption", nullptr));
    } // retranslateUi

};

namespace Ui {
    class KNetAttach: public Ui_KNetAttach {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KNETATTACH_H

