/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.impanel.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "impaneladaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ImpanelAdaptor
 */

ImpanelAdaptor::ImpanelAdaptor(PanelAgent *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ImpanelAdaptor::~ImpanelAdaptor()
{
    // destructor
}

/*
 * Implementation of adaptor class Impanel2Adaptor
 */

Impanel2Adaptor::Impanel2Adaptor(PanelAgent *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Impanel2Adaptor::~Impanel2Adaptor()
{
    // destructor
}

void Impanel2Adaptor::SetLookupTable(const QStringList &label, const QStringList &text, const QStringList &attr, bool hasPrev, bool hasNext, int cursor, int layout)
{
    // handle method call org.kde.impanel2.SetLookupTable
    parent()->SetLookupTable(label, text, attr, hasPrev, hasNext, cursor, layout);
}

void Impanel2Adaptor::SetSpotRect(int x, int y, int w, int h)
{
    // handle method call org.kde.impanel2.SetSpotRect
    parent()->SetSpotRect(x, y, w, h);
}


#include "moc_impaneladaptor.cpp"
