/****************************************************************************
** Meta object code from reading C++ file 'resourcescoring_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "resourcescoring_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcescoring_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeActivityManagerResourcesScoringInterface::qt_create_metaobjectdata<qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeActivityManagerResourcesScoringInterface",
        "EarlierStatsDeleted",
        "",
        "activity",
        "months",
        "RecentStatsDeleted",
        "count",
        "what",
        "ResourceScoreDeleted",
        "client",
        "resource",
        "ResourceScoreUpdated",
        "score",
        "lastUpdate",
        "firstUpdate",
        "DeleteEarlierStats",
        "QDBusPendingReply<>",
        "DeleteRecentStats",
        "DeleteStatsForResource"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'EarlierStatsDeleted'
        QtMocHelpers::SignalData<void(const QString &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'RecentStatsDeleted'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'ResourceScoreDeleted'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'ResourceScoreUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, double, uint, uint)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 }, { QMetaType::Double, 12 },
            { QMetaType::UInt, 13 }, { QMetaType::UInt, 14 },
        }}),
        // Slot 'DeleteEarlierStats'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, int)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'DeleteRecentStats'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, int, const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'DeleteStatsForResource'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeActivityManagerResourcesScoringInterface, qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeActivityManagerResourcesScoringInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeActivityManagerResourcesScoringInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeActivityManagerResourcesScoringInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->EarlierStatsDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->RecentStatsDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->ResourceScoreDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->ResourceScoreUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[6]))); break;
        case 4: { QDBusPendingReply<> _r = _t->DeleteEarlierStats((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->DeleteRecentStats((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->DeleteStatsForResource((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerResourcesScoringInterface::*)(const QString & , int )>(_a, &OrgKdeActivityManagerResourcesScoringInterface::EarlierStatsDeleted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerResourcesScoringInterface::*)(const QString & , int , const QString & )>(_a, &OrgKdeActivityManagerResourcesScoringInterface::RecentStatsDeleted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerResourcesScoringInterface::*)(const QString & , const QString & , const QString & )>(_a, &OrgKdeActivityManagerResourcesScoringInterface::ResourceScoreDeleted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerResourcesScoringInterface::*)(const QString & , const QString & , const QString & , double , uint , uint )>(_a, &OrgKdeActivityManagerResourcesScoringInterface::ResourceScoreUpdated, 3))
            return;
    }
}

const QMetaObject *OrgKdeActivityManagerResourcesScoringInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeActivityManagerResourcesScoringInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46OrgKdeActivityManagerResourcesScoringInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeActivityManagerResourcesScoringInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeActivityManagerResourcesScoringInterface::EarlierStatsDeleted(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgKdeActivityManagerResourcesScoringInterface::RecentStatsDeleted(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void OrgKdeActivityManagerResourcesScoringInterface::ResourceScoreDeleted(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void OrgKdeActivityManagerResourcesScoringInterface::ResourceScoreUpdated(const QString & _t1, const QString & _t2, const QString & _t3, double _t4, uint _t5, uint _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}
QT_WARNING_POP
