// This file is generated by kconfig_compiler_kf6 from kcmaccessibilityactivationgestures.kcfg.
// All changes you do to this file will be lost.

#include "kcmaccessibilityactivationgestures.h"

ActivationGesturesSettings::ActivationGesturesSettings( QObject *parent )
  : KConfigSkeleton( QStringLiteral( "kaccessrc" ) )
{
  setParent(parent);
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&ActivationGesturesSettings::itemChanged);

  setCurrentGroup( QStringLiteral( "Keyboard" ) );

  KConfigCompilerSignallingItem  *itemGestures;
  KConfigSkeleton::ItemBool  *innerItemGestures;
  innerItemGestures = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Gestures" ), mGestures, false );
  itemGestures = new KConfigCompilerSignallingItem(innerItemGestures, this, notifyFunction, signalGesturesChanged);
  itemGestures->setWriteFlags(KConfigBase::Notify);
  addItem( itemGestures, QStringLiteral( "Gestures" ) );
  KConfigCompilerSignallingItem  *itemGestureConfirmation;
  KConfigSkeleton::ItemBool  *innerItemGestureConfirmation;
  innerItemGestureConfirmation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "GestureConfirmation" ), mGestureConfirmation, false );
  itemGestureConfirmation = new KConfigCompilerSignallingItem(innerItemGestureConfirmation, this, notifyFunction, signalGestureConfirmationChanged);
  itemGestureConfirmation->setWriteFlags(KConfigBase::Notify);
  addItem( itemGestureConfirmation, QStringLiteral( "GestureConfirmation" ) );
  KConfigCompilerSignallingItem  *itemKeyboardNotifyAccess;
  KConfigSkeleton::ItemBool  *innerItemKeyboardNotifyAccess;
  innerItemKeyboardNotifyAccess = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "kNotifyAccessX" ), mKeyboardNotifyAccess, false );
  itemKeyboardNotifyAccess = new KConfigCompilerSignallingItem(innerItemKeyboardNotifyAccess, this, notifyFunction, signalKeyboardNotifyAccessChanged);
  itemKeyboardNotifyAccess->setWriteFlags(KConfigBase::Notify);
  addItem( itemKeyboardNotifyAccess, QStringLiteral( "KeyboardNotifyAccess" ) );
  KConfigCompilerSignallingItem  *itemAccessXTimeout;
  KConfigSkeleton::ItemBool  *innerItemAccessXTimeout;
  innerItemAccessXTimeout = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AccessXTimeout" ), mAccessXTimeout, false );
  itemAccessXTimeout = new KConfigCompilerSignallingItem(innerItemAccessXTimeout, this, notifyFunction, signalAccessXTimeoutChanged);
  itemAccessXTimeout->setWriteFlags(KConfigBase::Notify);
  addItem( itemAccessXTimeout, QStringLiteral( "AccessXTimeout" ) );
  KConfigCompilerSignallingItem  *itemAccessXTimeoutDelay;
  KConfigSkeleton::ItemInt  *innerItemAccessXTimeoutDelay;
  innerItemAccessXTimeoutDelay = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "AccessXTimeoutDelay" ), mAccessXTimeoutDelay, 30 );
  itemAccessXTimeoutDelay = new KConfigCompilerSignallingItem(innerItemAccessXTimeoutDelay, this, notifyFunction, signalAccessXTimeoutDelayChanged);
  itemAccessXTimeoutDelay->setWriteFlags(KConfigBase::Notify);
  addItem( itemAccessXTimeoutDelay, QStringLiteral( "AccessXTimeoutDelay" ) );
  KConfigCompilerSignallingItem  *itemAccessXBeep;
  KConfigSkeleton::ItemBool  *innerItemAccessXBeep;
  innerItemAccessXBeep = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "AccessXBeep" ), mAccessXBeep, true );
  itemAccessXBeep = new KConfigCompilerSignallingItem(innerItemAccessXBeep, this, notifyFunction, signalAccessXBeepChanged);
  itemAccessXBeep->setWriteFlags(KConfigBase::Notify);
  addItem( itemAccessXBeep, QStringLiteral( "AccessXBeep" ) );
}

bool ActivationGesturesSettings::defaultGesturesValue_helper() const
{

  return false;
}

bool ActivationGesturesSettings::defaultGestureConfirmationValue_helper() const
{

  return false;
}

bool ActivationGesturesSettings::defaultKeyboardNotifyAccessValue_helper() const
{

  return false;
}

bool ActivationGesturesSettings::defaultAccessXTimeoutValue_helper() const
{

  return false;
}

int ActivationGesturesSettings::defaultAccessXTimeoutDelayValue_helper() const
{

  return 30;
}

bool ActivationGesturesSettings::defaultAccessXBeepValue_helper() const
{

  return true;
}

ActivationGesturesSettings::~ActivationGesturesSettings()
{
}


void ActivationGesturesSettings::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalGesturesChanged:
    Q_EMIT GesturesChanged();
    break;
  case signalGestureConfirmationChanged:
    Q_EMIT GestureConfirmationChanged();
    break;
  case signalKeyboardNotifyAccessChanged:
    Q_EMIT KeyboardNotifyAccessChanged();
    break;
  case signalAccessXTimeoutChanged:
    Q_EMIT AccessXTimeoutChanged();
    break;
  case signalAccessXTimeoutDelayChanged:
    Q_EMIT AccessXTimeoutDelayChanged();
    break;
  case signalAccessXBeepChanged:
    Q_EMIT AccessXBeepChanged();
    break;
  }
}
