/****************************************************************************
** Meta object code from reading C++ file 'smserversettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../smserversettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'smserversettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16SMServerSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto SMServerSettings::qt_create_metaobjectdata<qt_meta_tag_ZN16SMServerSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SMServerSettings",
        "confirmLogoutChanged",
        "",
        "shutdownTypeChanged",
        "loginModeChanged",
        "excludeAppsChanged",
        "confirmLogout",
        "isConfirmLogoutImmutable",
        "defaultConfirmLogoutValue",
        "shutdownType",
        "isShutdownTypeImmutable",
        "defaultShutdownTypeValue",
        "loginMode",
        "isLoginModeImmutable",
        "defaultLoginModeValue",
        "excludeApps",
        "isExcludeAppsImmutable",
        "LoginModeType",
        "restorePreviousLogout",
        "restoreSavedSession",
        "emptySession"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'confirmLogoutChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shutdownTypeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loginModeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludeAppsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'confirmLogout'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isConfirmLogoutImmutable'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultConfirmLogoutValue'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shutdownType'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isShutdownTypeImmutable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShutdownTypeValue'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loginMode'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isLoginModeImmutable'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLoginModeValue'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'excludeApps'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isExcludeAppsImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LoginModeType'
        QtMocHelpers::EnumData<enum LoginModeType>(17, 17, QMC::EnumFlags{}).add({
            {   18, LoginModeType::restorePreviousLogout },
            {   19, LoginModeType::restoreSavedSession },
            {   20, LoginModeType::emptySession },
        }),
    };
    return QtMocHelpers::metaObjectData<SMServerSettings, qt_meta_tag_ZN16SMServerSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SMServerSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SMServerSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SMServerSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16SMServerSettingsE_t>.metaTypes,
    nullptr
} };

void SMServerSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SMServerSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->confirmLogoutChanged(); break;
        case 1: _t->shutdownTypeChanged(); break;
        case 2: _t->loginModeChanged(); break;
        case 3: _t->excludeAppsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SMServerSettings::*)()>(_a, &SMServerSettings::confirmLogoutChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SMServerSettings::*)()>(_a, &SMServerSettings::shutdownTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SMServerSettings::*)()>(_a, &SMServerSettings::loginModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SMServerSettings::*)()>(_a, &SMServerSettings::excludeAppsChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->confirmLogout(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isConfirmLogoutImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultConfirmLogoutValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->shutdownType(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isShutdownTypeImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultShutdownTypeValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->loginMode(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isLoginModeImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultLoginModeValue(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->excludeApps(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isExcludeAppsImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setConfirmLogout(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShutdownType(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setLoginMode(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setExcludeApps(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SMServerSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SMServerSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16SMServerSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int SMServerSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SMServerSettings::confirmLogoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SMServerSettings::shutdownTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SMServerSettings::loginModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SMServerSettings::excludeAppsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
