/****************************************************************************
** Meta object code from reading C++ file 'calibrationtool.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-desktop-6.7.4/kcms/tablet/calibrationtool.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calibrationtool.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15CalibrationToolE_t {};
} // unnamed namespace

template <> constexpr inline auto CalibrationTool::qt_create_metaobjectdata<qt_meta_tag_ZN15CalibrationToolE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalibrationTool",
        "stateChanged",
        "",
        "calibrationCreated",
        "QMatrix4x4",
        "matrix",
        "currentTargetChanged",
        "widthChanged",
        "heightChanged",
        "resetSecondsLeftChanged",
        "resetFromSaved",
        "calibrate",
        "touchX",
        "touchY",
        "screenX",
        "screenY",
        "setCalibrationMatrix",
        "KWinDevices::InputDevice*",
        "device",
        "restoreDefaults",
        "reset",
        "state",
        "State",
        "currentTarget",
        "width",
        "height",
        "resetSecondsLeft",
        "Calibrating",
        "Confirming",
        "Testing"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calibrationCreated'
        QtMocHelpers::SignalData<void(const QMatrix4x4 &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'currentTargetChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetSecondsLeftChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetFromSaved'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'calibrate'
        QtMocHelpers::SlotData<void(double, double, double, double)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 12 }, { QMetaType::Double, 13 }, { QMetaType::Double, 14 }, { QMetaType::Double, 15 },
        }}),
        // Slot 'setCalibrationMatrix'
        QtMocHelpers::SlotData<void(KWinDevices::InputDevice *, const QMatrix4x4 &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'restoreDefaults'
        QtMocHelpers::SlotData<void(KWinDevices::InputDevice *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'currentTarget'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'width'
        QtMocHelpers::PropertyData<float>(24, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'height'
        QtMocHelpers::PropertyData<float>(25, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'resetSecondsLeft'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(22, 22, QMC::EnumIsScoped).add({
            {   27, State::Calibrating },
            {   28, State::Confirming },
            {   29, State::Testing },
        }),
    };
    return QtMocHelpers::metaObjectData<CalibrationTool, qt_meta_tag_ZN15CalibrationToolE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalibrationTool::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalibrationToolE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalibrationToolE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalibrationToolE_t>.metaTypes,
    nullptr
} };

void CalibrationTool::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalibrationTool *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->calibrationCreated((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1]))); break;
        case 2: _t->currentTargetChanged(); break;
        case 3: _t->widthChanged(); break;
        case 4: _t->heightChanged(); break;
        case 5: _t->resetSecondsLeftChanged(); break;
        case 6: _t->resetFromSaved(); break;
        case 7: _t->calibrate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4]))); break;
        case 8: _t->setCalibrationMatrix((*reinterpret_cast<std::add_pointer_t<KWinDevices::InputDevice*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[2]))); break;
        case 9: _t->restoreDefaults((*reinterpret_cast<std::add_pointer_t<KWinDevices::InputDevice*>>(_a[1]))); break;
        case 10: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWinDevices::InputDevice* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWinDevices::InputDevice* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)()>(_a, &CalibrationTool::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)(const QMatrix4x4 & )>(_a, &CalibrationTool::calibrationCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)()>(_a, &CalibrationTool::currentTargetChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)()>(_a, &CalibrationTool::widthChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)()>(_a, &CalibrationTool::heightChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)()>(_a, &CalibrationTool::resetSecondsLeftChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalibrationTool::*)()>(_a, &CalibrationTool::resetFromSaved, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->currentTarget(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->width(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->height(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->resetSecondsLeft(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setWidth(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CalibrationTool::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalibrationTool::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalibrationToolE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CalibrationTool::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void CalibrationTool::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CalibrationTool::calibrationCreated(const QMatrix4x4 & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CalibrationTool::currentTargetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CalibrationTool::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CalibrationTool::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CalibrationTool::resetSecondsLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CalibrationTool::resetFromSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
