/****************************************************************************
** Meta object code from reading C++ file 'krunnersettingsbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../krunnersettingsbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'krunnersettingsbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19KRunnerSettingsBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto KRunnerSettingsBase::qt_create_metaobjectdata<qt_meta_tag_ZN19KRunnerSettingsBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KRunnerSettingsBase",
        "freeFloatingChanged",
        "",
        "historyBehaviorChanged",
        "retainPriorSearchChanged",
        "freeFloating",
        "isFreeFloatingImmutable",
        "defaultFreeFloatingValue",
        "historyBehavior",
        "isHistoryBehaviorImmutable",
        "defaultHistoryBehaviorValue",
        "retainPriorSearch",
        "isRetainPriorSearchImmutable",
        "defaultRetainPriorSearchValue",
        "EnumHistoryBehavior",
        "Disabled",
        "ImmediateCompletion",
        "CompletionSuggestion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'freeFloatingChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'historyBehaviorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'retainPriorSearchChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'freeFloating'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isFreeFloatingImmutable'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFreeFloatingValue'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'historyBehavior'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isHistoryBehaviorImmutable'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHistoryBehaviorValue'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'retainPriorSearch'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isRetainPriorSearchImmutable'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRetainPriorSearchValue'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EnumHistoryBehavior'
        QtMocHelpers::EnumData<enum EnumHistoryBehavior>(14, 14, QMC::EnumFlags{}).add({
            {   15, EnumHistoryBehavior::Disabled },
            {   16, EnumHistoryBehavior::ImmediateCompletion },
            {   17, EnumHistoryBehavior::CompletionSuggestion },
        }),
    };
    return QtMocHelpers::metaObjectData<KRunnerSettingsBase, qt_meta_tag_ZN19KRunnerSettingsBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KRunnerSettingsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KRunnerSettingsBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KRunnerSettingsBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19KRunnerSettingsBaseE_t>.metaTypes,
    nullptr
} };

void KRunnerSettingsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KRunnerSettingsBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->freeFloatingChanged(); break;
        case 1: _t->historyBehaviorChanged(); break;
        case 2: _t->retainPriorSearchChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KRunnerSettingsBase::*)()>(_a, &KRunnerSettingsBase::freeFloatingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KRunnerSettingsBase::*)()>(_a, &KRunnerSettingsBase::historyBehaviorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KRunnerSettingsBase::*)()>(_a, &KRunnerSettingsBase::retainPriorSearchChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->freeFloating(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isFreeFloatingImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultFreeFloatingValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->historyBehavior(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isHistoryBehaviorImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultHistoryBehaviorValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->retainPriorSearch(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isRetainPriorSearchImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultRetainPriorSearchValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFreeFloating(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setHistoryBehavior(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setRetainPriorSearch(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KRunnerSettingsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KRunnerSettingsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19KRunnerSettingsBaseE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int KRunnerSettingsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KRunnerSettingsBase::freeFloatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KRunnerSettingsBase::historyBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KRunnerSettingsBase::retainPriorSearchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
